% phonenumbers package: phonenumbers-AT.def
% Module for Austrian telephone numbers
% Author: K. Wehr
% Version: 2.6
% Date: 2025-05-06
\clist_const:Nn \c_phone_AT_ortsvorwahlen_clist {01,
02142,
02143,
02144,
02145,
02146,
02147,
02160,
02162,
02163,
02164,
02165,
02166,
02167,
02168,
02169,
02172,
02173,
02174,
02175,
02176,
02177,
02212,
02213,
02214,
02215,
02216,
02230,
02231,
02232,
02233,
02234,
02235,
02236,
02237,
02238,
02239,
02242,
02243,
02244,
02245,
02246,
02247,
02248,
02249,
02252,
02253,
02254,
02255,
02256,
02257,
02258,
02259,
02262,
02263,
02264,
02265,
02266,
02267,
02268,
02269,
02271,
02272,
02273,
02274,
02275,
02276,
02277,
02278,
02279,
02282,
02283,
02284,
02285,
02286,
02287,
02288,
02289,
02522,
02523,
02524,
02525,
02526,
02527,
02532,
02533,
02534,
02535,
02536,
02538,
02552,
02554,
02555,
02556,
02557,
02572,
02573,
02574,
02575,
02576,
02577,
02610,
02611,
02612,
02613,
02614,
02615,
02616,
02617,
02618,
02619,
02620,
02621,
02622,
02623,
02624,
02625,
02626,
02627,
02628,
02629,
02630,
02631,
02632,
02633,
02634,
02635,
02636,
02637,
02638,
02639,
02641,
02642,
02643,
02644,
02645,
02646,
02647,
02648,
02649,
02662,
02663,
02664,
02665,
02666,
02667,
02672,
02673,
02674,
02680,
02682,
02683,
02684,
02685,
02686,
02687,
02688,
02689,
02711,
02712,
02713,
02714,
02715,
02716,
02717,
02718,
02719,
02722,
02723,
02724,
02725,
02726,
02728,
02731,
02732,
02733,
02734,
02735,
02736,
02738,
02739,
02741,
02742,
02743,
02744,
02745,
02746,
02747,
02748,
02749,
02752,
02753,
02754,
02755,
02756,
02757,
02758,
02762,
02763,
02764,
02765,
02766,
02767,
02768,
02769,
02772,
02773,
02774,
02782,
02783,
02784,
02786,
02812,
02813,
02814,
02815,
02816,
02822,
02823,
02824,
02825,
02826,
02827,
02828,
02829,
02841,
02842,
02843,
02844,
02845,
02846,
02847,
02848,
02849,
02852,
02853,
02854,
02855,
02856,
02857,
02858,
02859,
02862,
02863,
02864,
02865,
02872,
02873,
02874,
02875,
02876,
02877,
02878,
02912,
02913,
02914,
02915,
02916,
02942,
02943,
02944,
02945,
02946,
02947,
02948,
02949,
02951,
02952,
02953,
02954,
02955,
02956,
02957,
02958,
02959,
02982,
02983,
02984,
02985,
02986,
02987,
02988,
02989,
03112,
03113,
03114,
03115,
03116,
03117,
03118,
03119,
03123,
03124,
03125,
03126,
03127,
03132,
03133,
03134,
03135,
03136,
03137,
03140,
03141,
03142,
03143,
03144,
03145,
03146,
03147,
03148,
03149,
03150,
03151,
03152,
03153,
03155,
03157,
03158,
03159,
0316,
03170,
03171,
03172,
03173,
03174,
03175,
03176,
03177,
03178,
03179,
03182,
03183,
03184,
03185,
03322,
03323,
03324,
03325,
03326,
03327,
03328,
03329,
03331,
03332,
03333,
03334,
03335,
03336,
03337,
03338,
03339,
03352,
03353,
03354,
03355,
03356,
03357,
03358,
03359,
03362,
03363,
03364,
03365,
03366,
03382,
03383,
03385,
03386,
03387,
03452,
03453,
03454,
03455,
03456,
03457,
03460,
03461,
03462,
03463,
03464,
03465,
03466,
03467,
03468,
03469,
03472,
03473,
03474,
03475,
03476,
03477,
03512,
03513,
03514,
03515,
03516,
03532,
03533,
03534,
03535,
03536,
03537,
03571,
03572,
03573,
03574,
03575,
03576,
03577,
03578,
03579,
03581,
03582,
03583,
03584,
03585,
03586,
03587,
03588,
03611,
03612,
03613,
03614,
03615,
03616,
03617,
03618,
03619,
03622,
03623,
03624,
03631,
03632,
03633,
03634,
03635,
03636,
03637,
03638,
03680,
03682,
03683,
03684,
03685,
03686,
03687,
03688,
03689,
03832,
03833,
03834,
03842,
03843,
03844,
03845,
03846,
03847,
03848,
03849,
03852,
03853,
03854,
03855,
03856,
03857,
03858,
03859,
03861,
03862,
03863,
03864,
03865,
03866,
03867,
03868,
03869,
03882,
03883,
03884,
03885,
03886,
04212,
04213,
04214,
04215,
04220,
04221,
04223,
04224,
04225,
04226,
04227,
04228,
04229,
04230,
04231,
04232,
04233,
04234,
04235,
04236,
04237,
04238,
04239,
04240,
04242,
04243,
04244,
04245,
04246,
04247,
04248,
04252,
04253,
04254,
04255,
04256,
04257,
04258,
04262,
04263,
04264,
04265,
04266,
04267,
04268,
04269,
04271,
04272,
04273,
04274,
04275,
04276,
04277,
04278,
04279,
04282,
04283,
04284,
04285,
04286,
04350,
04352,
04353,
04354,
04355,
04356,
04357,
04358,
04359,
0463,
04710,
04712,
04713,
04714,
04715,
04716,
04717,
04718,
04732,
04733,
04734,
04735,
04736,
04761,
04762,
04766,
04767,
04768,
04769,
04782,
04783,
04784,
04785,
04822,
04823,
04824,
04825,
04826,
04842,
04843,
04846,
04847,
04848,
04852,
04853,
04855,
04858,
04872,
04873,
04874,
04875,
04876,
04877,
04879,
0512,
05212,
05213,
05214,
05223,
05224,
05225,
05226,
05230,
05232,
05234,
05236,
05238,
05239,
05242,
05243,
05244,
05245,
05246,
05248,
05252,
05253,
05254,
05255,
05256,
05262,
05263,
05264,
05265,
05266,
05272,
05273,
05274,
05275,
05276,
05278,
05279,
05280,
05282,
05283,
05284,
05285,
05286,
05287,
05288,
05289,
05331,
05332,
05333,
05334,
05335,
05336,
05337,
05338,
05339,
05352,
05353,
05354,
05355,
05356,
05357,
05358,
05359,
05372,
05373,
05374,
05375,
05376,
05412,
05413,
05414,
05417,
05418,
05441,
05442,
05443,
05444,
05445,
05446,
05447,
05448,
05449,
05472,
05473,
05474,
05475,
05476,
05477,
05510,
05512,
05513,
05514,
05515,
05516,
05517,
05518,
05519,
05522,
05523,
05524,
05525,
05526,
05550,
05552,
05553,
05554,
05556,
05557,
05558,
05559,
05572,
05573,
05574,
05575,
05576,
05577,
05578,
05579,
05582,
05583,
05585,
05632,
05633,
05634,
05635,
05672,
05673,
05674,
05675,
05676,
05677,
05678,
06131,
06132,
06133,
06134,
06135,
06136,
06137,
06138,
06212,
06213,
06214,
06215,
06216,
06217,
06219,
06221,
06223,
06224,
06225,
06226,
06227,
06228,
06229,
06232,
06233,
06234,
06235,
06240,
06241,
06242,
06243,
06244,
06245,
06246,
06247,
06272,
06274,
06276,
06277,
06278,
06412,
06413,
06414,
06415,
06416,
06417,
06418,
06432,
06433,
06434,
06452,
06453,
06454,
06455,
06456,
06457,
06458,
06461,
06462,
06463,
06466,
06467,
06468,
06470,
06471,
06472,
06473,
06474,
06475,
06476,
06477,
06478,
06479,
06483,
06484,
06541,
06542,
06543,
06544,
06545,
06546,
06547,
06548,
06549,
06562,
06563,
06564,
06565,
06566,
06582,
06583,
06584,
06588,
06589,
0662,
07211,
07212,
07213,
07214,
07215,
07216,
07217,
07218,
07219,
07221,
07223,
07224,
07225,
07226,
07227,
07228,
07229,
07230,
07231,
07232,
07233,
07234,
07235,
07236,
07237,
07238,
07239,
07240,
07241,
07242,
07243,
07244,
07245,
07246,
07247,
07248,
07249,
07250,
07251,
07252,
07253,
07254,
07255,
07256,
07257,
07258,
07259,
07260,
07261,
07262,
07263,
07264,
07265,
07266,
07267,
07268,
07269,
07272,
07273,
07274,
07276,
07277,
07278,
07279,
07280,
07281,
07282,
07283,
07284,
07285,
07286,
07287,
07288,
07289,
0732,
07353,
07355,
07357,
07412,
07413,
07414,
07415,
07416,
07432,
07433,
07434,
07435,
07442,
07443,
07444,
07445,
07448,
07471,
07472,
07473,
07474,
07475,
07476,
07477,
07478,
07479,
07480,
07482,
07483,
07484,
07485,
07486,
07487,
07488,
07489,
07562,
07563,
07564,
07565,
07566,
07582,
07583,
07584,
07585,
07586,
07587,
07588,
07612,
07613,
07614,
07615,
07616,
07617,
07618,
07619,
07662,
07663,
07664,
07665,
07666,
07667,
07672,
07673,
07674,
07675,
07676,
07682,
07683,
07684,
07711,
07712,
07713,
07714,
07716,
07717,
07718,
07719,
07722,
07723,
07724,
07727,
07728,
07729,
07732,
07733,
07734,
07735,
07736,
07742,
07743,
07744,
07745,
07746,
07747,
07748,
07750,
07751,
07752,
07753,
07754,
07755,
07757,
07758,
07759,
07762,
07763,
07764,
07765,
07766,
07767,
07941,
07942,
07943,
07944,
07945,
07946,
07947,
07948,
07949,
07952,
07953,
07954,
07955,
07956}
\clist_const:Nn \c_phone_AT_sondervorwahlen_clist {0501,
0502,
0503,
0504,
0505,
0506,
0507,
0508,
0509,
0517,
057,
059,
0650,
0651,
0652,
0653,
0655,
0657,
0659,
0660,
0661,
0663,
0664,
0665,
0666,
0667,
0668,
0669,
067,
068,
069,
0711,
0718,
0720,
0780,
0800,
0804,
0810,
0820,
0821,
0828,
089,
0900,
0901,
0930,
0931,
0939}
\tl_const:cn {c_phone_AT_ortsname_01_tl} {Wien}
\tl_const:cn {c_phone_AT_ortsname_02142_tl} {Gattendorf}
\tl_const:cn {c_phone_AT_ortsname_02143_tl} {Kittsee}
\tl_const:cn {c_phone_AT_ortsname_02144_tl} {Deutsch~Jahrndorf}
\tl_const:cn {c_phone_AT_ortsname_02145_tl} {Prellenkirchen}
\tl_const:cn {c_phone_AT_ortsname_02146_tl} {Nickelsdorf}
\tl_const:cn {c_phone_AT_ortsname_02147_tl} {Zurndorf}
\tl_const:cn {c_phone_AT_ortsname_02160_tl} {Jois}
\tl_const:cn {c_phone_AT_ortsname_02162_tl} {Bruck~an~der~Leitha}
\tl_const:cn {c_phone_AT_ortsname_02163_tl} {Petronell-Carnuntum}
\tl_const:cn {c_phone_AT_ortsname_02164_tl} {Rohrau}
\tl_const:cn {c_phone_AT_ortsname_02165_tl} {Hainburg~an~der~Donau}
\tl_const:cn {c_phone_AT_ortsname_02166_tl} {Parndorf}
\tl_const:cn {c_phone_AT_ortsname_02167_tl} {Neusiedl~am~See}
\tl_const:cn {c_phone_AT_ortsname_02168_tl} {Mannersdorf~am~Leithagebirge}
\tl_const:cn {c_phone_AT_ortsname_02169_tl} {Trautmannsdorf~an~der~Leitha}
\tl_const:cn {c_phone_AT_ortsname_02172_tl} {Frauenkirchen}
\tl_const:cn {c_phone_AT_ortsname_02173_tl} {Gols}
\tl_const:cn {c_phone_AT_ortsname_02174_tl} {Wallern~im~Burgenland}
\tl_const:cn {c_phone_AT_ortsname_02175_tl} {Apetlon}
\tl_const:cn {c_phone_AT_ortsname_02176_tl} {Tadten}
\tl_const:cn {c_phone_AT_ortsname_02177_tl} {Podersdorf~am~See}
\tl_const:cn {c_phone_AT_ortsname_02212_tl} {Orth~an~der~Donau}
\tl_const:cn {c_phone_AT_ortsname_02213_tl} {Lassee}
\tl_const:cn {c_phone_AT_ortsname_02214_tl} {Kopfstetten}
\tl_const:cn {c_phone_AT_ortsname_02215_tl} {Probstdorf}
\tl_const:cn {c_phone_AT_ortsname_02216_tl} {Leopoldsdorf~im~Marchfelde}
\tl_const:cn {c_phone_AT_ortsname_02230_tl} {Schwadorf}
\tl_const:cn {c_phone_AT_ortsname_02231_tl} {Purkersdorf}
\tl_const:cn {c_phone_AT_ortsname_02232_tl} {Fischamend}
\tl_const:cn {c_phone_AT_ortsname_02233_tl} {Pressbaum}
\tl_const:cn {c_phone_AT_ortsname_02234_tl} {Gramatneusiedl}
\tl_const:cn {c_phone_AT_ortsname_02235_tl} {Maria-Lanzendorf}
\tl_const:cn {c_phone_AT_ortsname_02236_tl} {M\"odling}
\tl_const:cn {c_phone_AT_ortsname_02237_tl} {Gaaden}
\tl_const:cn {c_phone_AT_ortsname_02238_tl} {Kaltenleutgeben}
\tl_const:cn {c_phone_AT_ortsname_02239_tl} {Breitenfurt~bei~Wien}
\tl_const:cn {c_phone_AT_ortsname_02242_tl} {St.~Andr\"a-W\"ordern}
\tl_const:cn {c_phone_AT_ortsname_02243_tl} {Klosterneuburg}
\tl_const:cn {c_phone_AT_ortsname_02244_tl} {Langenzersdorf}
\tl_const:cn {c_phone_AT_ortsname_02245_tl} {Wolkersdorf~im~Weinviertel}
\tl_const:cn {c_phone_AT_ortsname_02246_tl} {Gerasdorf~bei~Wien}
\tl_const:cn {c_phone_AT_ortsname_02247_tl} {Deutsch-Wagram}
\tl_const:cn {c_phone_AT_ortsname_02248_tl} {Markgrafneusiedl}
\tl_const:cn {c_phone_AT_ortsname_02249_tl} {Gro\ss-Enzersdorf}
\tl_const:cn {c_phone_AT_ortsname_02252_tl} {Baden}
\tl_const:cn {c_phone_AT_ortsname_02253_tl} {Oberwaltersdorf}
\tl_const:cn {c_phone_AT_ortsname_02254_tl} {Ebreichsdorf}
\tl_const:cn {c_phone_AT_ortsname_02255_tl} {Deutsch-Brodersdorf}
\tl_const:cn {c_phone_AT_ortsname_02256_tl} {Leobersdorf}
\tl_const:cn {c_phone_AT_ortsname_02257_tl} {Klausen-Leopoldsdorf}
\tl_const:cn {c_phone_AT_ortsname_02258_tl} {Alland}
\tl_const:cn {c_phone_AT_ortsname_02259_tl} {M\"unchendorf}
\tl_const:cn {c_phone_AT_ortsname_02262_tl} {Korneuburg}
\tl_const:cn {c_phone_AT_ortsname_02263_tl} {Gro\ss ru\ss bach}
\tl_const:cn {c_phone_AT_ortsname_02264_tl} {R\"uckersdorf~(Harmannsdorf)}
\tl_const:cn {c_phone_AT_ortsname_02265_tl} {Hausleiten}
\tl_const:cn {c_phone_AT_ortsname_02266_tl} {Stockerau}
\tl_const:cn {c_phone_AT_ortsname_02267_tl} {Sierndorf}
\tl_const:cn {c_phone_AT_ortsname_02268_tl} {Gro\ss mugl}
\tl_const:cn {c_phone_AT_ortsname_02269_tl} {Niederfellabrunn}
\tl_const:cn {c_phone_AT_ortsname_02271_tl} {Ried~am~Riederberg}
\tl_const:cn {c_phone_AT_ortsname_02272_tl} {Tulln~an~der~Donau}
\tl_const:cn {c_phone_AT_ortsname_02273_tl} {Tulbing}
\tl_const:cn {c_phone_AT_ortsname_02274_tl} {Sieghartskirchen}
\tl_const:cn {c_phone_AT_ortsname_02275_tl} {Atzenbrugg}
\tl_const:cn {c_phone_AT_ortsname_02276_tl} {Reidling}
\tl_const:cn {c_phone_AT_ortsname_02277_tl} {Zwentendorf~an~der~Donau}
\tl_const:cn {c_phone_AT_ortsname_02278_tl} {Absdorf}
\tl_const:cn {c_phone_AT_ortsname_02279_tl} {Kirchberg~am~Wagram}
\tl_const:cn {c_phone_AT_ortsname_02282_tl} {G\"anserndorf}
\tl_const:cn {c_phone_AT_ortsname_02283_tl} {Angern~an~der~March}
\tl_const:cn {c_phone_AT_ortsname_02284_tl} {Oberweiden}
\tl_const:cn {c_phone_AT_ortsname_02285_tl} {Marchegg}
\tl_const:cn {c_phone_AT_ortsname_02286_tl} {Obersiebenbrunn}
\tl_const:cn {c_phone_AT_ortsname_02287_tl} {Strasshof~an~der~Nordbahn}
\tl_const:cn {c_phone_AT_ortsname_02288_tl} {Auersthal}
\tl_const:cn {c_phone_AT_ortsname_02289_tl} {Matzen-Raggendorf}
\tl_const:cn {c_phone_AT_ortsname_02522_tl} {Laa~an~der~Thaya}
\tl_const:cn {c_phone_AT_ortsname_02523_tl} {Kirchstetten~(Neudorf~bei~Staatz)}
\tl_const:cn {c_phone_AT_ortsname_02524_tl} {Kautendorf}
\tl_const:cn {c_phone_AT_ortsname_02525_tl} {Gnadendorf}
\tl_const:cn {c_phone_AT_ortsname_02526_tl} {Stronsdorf}
\tl_const:cn {c_phone_AT_ortsname_02527_tl} {Wulzeshofen}
\tl_const:cn {c_phone_AT_ortsname_02532_tl} {Zistersdorf}
\tl_const:cn {c_phone_AT_ortsname_02533_tl} {Neusiedl~an~der~Zaya}
\tl_const:cn {c_phone_AT_ortsname_02534_tl} {Niedersulz}
\tl_const:cn {c_phone_AT_ortsname_02535_tl} {Hohenau~an~der~March}
\tl_const:cn {c_phone_AT_ortsname_02536_tl} {Dr\"osing}
\tl_const:cn {c_phone_AT_ortsname_02538_tl} {Velm-G\"otzendorf}
\tl_const:cn {c_phone_AT_ortsname_02552_tl} {Poysdorf}
\tl_const:cn {c_phone_AT_ortsname_02554_tl} {St\"utzenhofen}
\tl_const:cn {c_phone_AT_ortsname_02555_tl} {Herrnbaumgarten}
\tl_const:cn {c_phone_AT_ortsname_02556_tl} {Gro\ss krut}
\tl_const:cn {c_phone_AT_ortsname_02557_tl} {Bernhardsthal}
\tl_const:cn {c_phone_AT_ortsname_02572_tl} {Mistelbach}
\tl_const:cn {c_phone_AT_ortsname_02573_tl} {Wilfersdorf}
\tl_const:cn {c_phone_AT_ortsname_02574_tl} {Gaweinstal}
\tl_const:cn {c_phone_AT_ortsname_02575_tl} {Ladendorf}
\tl_const:cn {c_phone_AT_ortsname_02576_tl} {Ernstbrunn}
\tl_const:cn {c_phone_AT_ortsname_02577_tl} {Asparn~an~der~Zaya}
\tl_const:cn {c_phone_AT_ortsname_02610_tl} {Horitschon}
\tl_const:cn {c_phone_AT_ortsname_02611_tl} {Mannersdorf~an~der~Rabnitz}
\tl_const:cn {c_phone_AT_ortsname_02612_tl} {Oberpullendorf}
\tl_const:cn {c_phone_AT_ortsname_02613_tl} {Deutschkreutz}
\tl_const:cn {c_phone_AT_ortsname_02614_tl} {Gro\ss warasdorf}
\tl_const:cn {c_phone_AT_ortsname_02615_tl} {Lutzmannsburg}
\tl_const:cn {c_phone_AT_ortsname_02616_tl} {Lockenhaus}
\tl_const:cn {c_phone_AT_ortsname_02617_tl} {Dra\ss markt}
\tl_const:cn {c_phone_AT_ortsname_02618_tl} {Markt~Sankt~Martin}
\tl_const:cn {c_phone_AT_ortsname_02619_tl} {Lackendorf}
\tl_const:cn {c_phone_AT_ortsname_02620_tl} {Willendorf}
\tl_const:cn {c_phone_AT_ortsname_02621_tl} {Sieggraben}
\tl_const:cn {c_phone_AT_ortsname_02622_tl} {Wiener~Neustadt}
\tl_const:cn {c_phone_AT_ortsname_02623_tl} {Pottendorf}
\tl_const:cn {c_phone_AT_ortsname_02624_tl} {Ebenfurth}
\tl_const:cn {c_phone_AT_ortsname_02625_tl} {Bad~Sauerbrunn}
\tl_const:cn {c_phone_AT_ortsname_02626_tl} {Mattersburg}
\tl_const:cn {c_phone_AT_ortsname_02627_tl} {Pitten}
\tl_const:cn {c_phone_AT_ortsname_02628_tl} {Felixdorf}
\tl_const:cn {c_phone_AT_ortsname_02629_tl} {Warth~(Nieder\"osterreich)}
\tl_const:cn {c_phone_AT_ortsname_02630_tl} {Ternitz}
\tl_const:cn {c_phone_AT_ortsname_02631_tl} {P\"ottsching}
\tl_const:cn {c_phone_AT_ortsname_02632_tl} {Pernitz}
\tl_const:cn {c_phone_AT_ortsname_02633_tl} {Markt~Piesting}
\tl_const:cn {c_phone_AT_ortsname_02634_tl} {Gutenstein}
\tl_const:cn {c_phone_AT_ortsname_02635_tl} {Neunkirchen}
\tl_const:cn {c_phone_AT_ortsname_02636_tl} {Puchberg~am~Schneeberg}
\tl_const:cn {c_phone_AT_ortsname_02637_tl} {Gr\"unbach~am~Schneeberg}
\tl_const:cn {c_phone_AT_ortsname_02638_tl} {Winzendorf-Muthmannsdorf}
\tl_const:cn {c_phone_AT_ortsname_02639_tl} {Bad~Fischau}
\tl_const:cn {c_phone_AT_ortsname_02641_tl} {Kirchberg~am~Wechsel}
\tl_const:cn {c_phone_AT_ortsname_02642_tl} {Aspangberg-St.~Peter}
\tl_const:cn {c_phone_AT_ortsname_02643_tl} {Lichtenegg}
\tl_const:cn {c_phone_AT_ortsname_02644_tl} {Grimmenstein}
\tl_const:cn {c_phone_AT_ortsname_02645_tl} {Wiesmath}
\tl_const:cn {c_phone_AT_ortsname_02646_tl} {Kirchschlag~in~der~Buckligen~Welt}
\tl_const:cn {c_phone_AT_ortsname_02647_tl} {Krumbach~(Nieder\"osterreich)}
\tl_const:cn {c_phone_AT_ortsname_02648_tl} {Hochneukirchen}
\tl_const:cn {c_phone_AT_ortsname_02649_tl} {M\"onichkirchen}
\tl_const:cn {c_phone_AT_ortsname_02662_tl} {Gloggnitz}
\tl_const:cn {c_phone_AT_ortsname_02663_tl} {Schottwien}
\tl_const:cn {c_phone_AT_ortsname_02664_tl} {Semmering}
\tl_const:cn {c_phone_AT_ortsname_02665_tl} {Prein~an~der~Rax}
\tl_const:cn {c_phone_AT_ortsname_02666_tl} {Reichenau~an~der~Rax}
\tl_const:cn {c_phone_AT_ortsname_02667_tl} {Schwarzau~im~Gebirge}
\tl_const:cn {c_phone_AT_ortsname_02672_tl} {Berndorf}
\tl_const:cn {c_phone_AT_ortsname_02673_tl} {Altenmarkt~an~der~Triesting}
\tl_const:cn {c_phone_AT_ortsname_02674_tl} {Weissenbach~an~der~Triesting}
\tl_const:cn {c_phone_AT_ortsname_02680_tl} {Sankt~Margarethen~im~Burgenland}
\tl_const:cn {c_phone_AT_ortsname_02682_tl} {Eisenstadt}
\tl_const:cn {c_phone_AT_ortsname_02683_tl} {Purbach~am~Neusiedler~See}
\tl_const:cn {c_phone_AT_ortsname_02684_tl} {Sch\"utzen~am~Gebirge}
\tl_const:cn {c_phone_AT_ortsname_02685_tl} {Rust}
\tl_const:cn {c_phone_AT_ortsname_02686_tl} {Dra\ss burg}
\tl_const:cn {c_phone_AT_ortsname_02687_tl} {Siegendorf}
\tl_const:cn {c_phone_AT_ortsname_02688_tl} {Steinbrunn}
\tl_const:cn {c_phone_AT_ortsname_02689_tl} {Hornstein}
\tl_const:cn {c_phone_AT_ortsname_02711_tl} {D\"urnstein}
\tl_const:cn {c_phone_AT_ortsname_02712_tl} {Aggsbach}
\tl_const:cn {c_phone_AT_ortsname_02713_tl} {Spitz}
\tl_const:cn {c_phone_AT_ortsname_02714_tl} {Rossatz}
\tl_const:cn {c_phone_AT_ortsname_02715_tl} {Wei\ss enkirchen~in~der~Wachau}
\tl_const:cn {c_phone_AT_ortsname_02716_tl} {Gf\"ohl}
\tl_const:cn {c_phone_AT_ortsname_02717_tl} {Unter-Meisling}
\tl_const:cn {c_phone_AT_ortsname_02718_tl} {Lichtenau~im~Waldviertel}
\tl_const:cn {c_phone_AT_ortsname_02719_tl} {Dro\ss}
\tl_const:cn {c_phone_AT_ortsname_02722_tl} {Kirchberg~an~der~Pielach}
\tl_const:cn {c_phone_AT_ortsname_02723_tl} {Rabenstein~an~der~Pielach}
\tl_const:cn {c_phone_AT_ortsname_02724_tl} {Schwarzenbach~an~der~Pielach}
\tl_const:cn {c_phone_AT_ortsname_02725_tl} {Frankenfels}
\tl_const:cn {c_phone_AT_ortsname_02726_tl} {Puchenstuben}
\tl_const:cn {c_phone_AT_ortsname_02728_tl} {Wienerbruck}
\tl_const:cn {c_phone_AT_ortsname_02731_tl} {Idolsberg}
\tl_const:cn {c_phone_AT_ortsname_02732_tl} {Krems~an~der~Donau}
\tl_const:cn {c_phone_AT_ortsname_02733_tl} {Sch\"onberg~am~Kamp}
\tl_const:cn {c_phone_AT_ortsname_02734_tl} {Langenlois}
\tl_const:cn {c_phone_AT_ortsname_02735_tl} {Hadersdorf~am~Kamp}
\tl_const:cn {c_phone_AT_ortsname_02736_tl} {Paudorf}
\tl_const:cn {c_phone_AT_ortsname_02738_tl} {Fels~am~Wagram}
\tl_const:cn {c_phone_AT_ortsname_02739_tl} {Tiefenfucha}
\tl_const:cn {c_phone_AT_ortsname_02741_tl} {Flinsbach}
\tl_const:cn {c_phone_AT_ortsname_02742_tl} {St.~P\"olten}
\tl_const:cn {c_phone_AT_ortsname_02743_tl} {B\"oheimkirchen}
\tl_const:cn {c_phone_AT_ortsname_02744_tl} {Kasten~bei~B\"oheimkirchen}
\tl_const:cn {c_phone_AT_ortsname_02745_tl} {Pyhra}
\tl_const:cn {c_phone_AT_ortsname_02746_tl} {Wilhelmsburg}
\tl_const:cn {c_phone_AT_ortsname_02747_tl} {Ober-Grafendorf}
\tl_const:cn {c_phone_AT_ortsname_02748_tl} {Kilb}
\tl_const:cn {c_phone_AT_ortsname_02749_tl} {Prinzersdorf}
\tl_const:cn {c_phone_AT_ortsname_02752_tl} {Melk}
\tl_const:cn {c_phone_AT_ortsname_02753_tl} {Gansbach}
\tl_const:cn {c_phone_AT_ortsname_02754_tl} {Loosdorf}
\tl_const:cn {c_phone_AT_ortsname_02755_tl} {Mank}
\tl_const:cn {c_phone_AT_ortsname_02756_tl} {St.~Leonhard~am~Forst}
\tl_const:cn {c_phone_AT_ortsname_02757_tl} {P\"ochlarn}
\tl_const:cn {c_phone_AT_ortsname_02758_tl} {P\"oggstall}
\tl_const:cn {c_phone_AT_ortsname_02762_tl} {Lilienfeld}
\tl_const:cn {c_phone_AT_ortsname_02763_tl} {St.~Veit~an~der~G\"olsen}
\tl_const:cn {c_phone_AT_ortsname_02764_tl} {Hainfeld}
\tl_const:cn {c_phone_AT_ortsname_02765_tl} {Kaumberg}
\tl_const:cn {c_phone_AT_ortsname_02766_tl} {Kleinzell}
\tl_const:cn {c_phone_AT_ortsname_02767_tl} {Hohenberg}
\tl_const:cn {c_phone_AT_ortsname_02768_tl} {St.~Aegyd~am~Neuwalde}
\tl_const:cn {c_phone_AT_ortsname_02769_tl} {T\"urnitz}
\tl_const:cn {c_phone_AT_ortsname_02772_tl} {Neulengbach}
\tl_const:cn {c_phone_AT_ortsname_02773_tl} {Eichgraben}
\tl_const:cn {c_phone_AT_ortsname_02774_tl} {Innermanzing}
\tl_const:cn {c_phone_AT_ortsname_02782_tl} {Herzogenburg}
\tl_const:cn {c_phone_AT_ortsname_02783_tl} {Traismauer}
\tl_const:cn {c_phone_AT_ortsname_02784_tl} {Perschling}
\tl_const:cn {c_phone_AT_ortsname_02786_tl} {Oberw\"olbling}
\tl_const:cn {c_phone_AT_ortsname_02812_tl} {Gro\ss\ Gerungs}
\tl_const:cn {c_phone_AT_ortsname_02813_tl} {Arbesbach}
\tl_const:cn {c_phone_AT_ortsname_02814_tl} {Langschlag}
\tl_const:cn {c_phone_AT_ortsname_02815_tl} {Gro\ss sch\"onau}
\tl_const:cn {c_phone_AT_ortsname_02816_tl} {Karlstift}
\tl_const:cn {c_phone_AT_ortsname_02822_tl} {Zwettl-Nieder\"osterreich}
\tl_const:cn {c_phone_AT_ortsname_02823_tl} {Gro\ss globnitz}
\tl_const:cn {c_phone_AT_ortsname_02824_tl} {Allentsteig}
\tl_const:cn {c_phone_AT_ortsname_02825_tl} {G\"opfritz~an~der~Wild}
\tl_const:cn {c_phone_AT_ortsname_02826_tl} {Rastenfeld}
\tl_const:cn {c_phone_AT_ortsname_02827_tl} {Sch\"onbach~(Nieder\"osterreich)}
\tl_const:cn {c_phone_AT_ortsname_02828_tl} {Rappottenstein}
\tl_const:cn {c_phone_AT_ortsname_02829_tl} {Schweiggers}
\tl_const:cn {c_phone_AT_ortsname_02841_tl} {Vitis}
\tl_const:cn {c_phone_AT_ortsname_02842_tl} {Waidhofen~an~der~Thaya}
\tl_const:cn {c_phone_AT_ortsname_02843_tl} {Dobersberg}
\tl_const:cn {c_phone_AT_ortsname_02844_tl} {Karlstein~an~der~Thaya}
\tl_const:cn {c_phone_AT_ortsname_02845_tl} {Weikertschlag~an~der~Thaya}
\tl_const:cn {c_phone_AT_ortsname_02846_tl} {Raabs~an~der~Thaya}
\tl_const:cn {c_phone_AT_ortsname_02847_tl} {Gro\ss-Siegharts}
\tl_const:cn {c_phone_AT_ortsname_02848_tl} {Pfaffenschlag~bei~Waidhofen~a.\,d.~Thaya}
\tl_const:cn {c_phone_AT_ortsname_02849_tl} {Schwarzenau}
\tl_const:cn {c_phone_AT_ortsname_02852_tl} {Gm\"und}
\tl_const:cn {c_phone_AT_ortsname_02853_tl} {Schrems}
\tl_const:cn {c_phone_AT_ortsname_02854_tl} {Kirchberg~am~Walde}
\tl_const:cn {c_phone_AT_ortsname_02855_tl} {Waldenstein}
\tl_const:cn {c_phone_AT_ortsname_02856_tl} {Weitra}
\tl_const:cn {c_phone_AT_ortsname_02857_tl} {Bad~Gro\ss pertholz}
\tl_const:cn {c_phone_AT_ortsname_02858_tl} {Moorbad~Harbach}
\tl_const:cn {c_phone_AT_ortsname_02859_tl} {Brand-Nagelberg}
\tl_const:cn {c_phone_AT_ortsname_02862_tl} {Heidenreichstein}
\tl_const:cn {c_phone_AT_ortsname_02863_tl} {Eggern}
\tl_const:cn {c_phone_AT_ortsname_02864_tl} {Kautzen}
\tl_const:cn {c_phone_AT_ortsname_02865_tl} {Litschau}
\tl_const:cn {c_phone_AT_ortsname_02872_tl} {Ottenschlag}
\tl_const:cn {c_phone_AT_ortsname_02873_tl} {Kottes}
\tl_const:cn {c_phone_AT_ortsname_02874_tl} {Martinsberg}
\tl_const:cn {c_phone_AT_ortsname_02875_tl} {Grafenschlag}
\tl_const:cn {c_phone_AT_ortsname_02876_tl} {Els}
\tl_const:cn {c_phone_AT_ortsname_02877_tl} {Grainbrunn}
\tl_const:cn {c_phone_AT_ortsname_02878_tl} {Bad~Traunstein}
\tl_const:cn {c_phone_AT_ortsname_02912_tl} {Geras}
\tl_const:cn {c_phone_AT_ortsname_02913_tl} {H\"otzelsdorf}
\tl_const:cn {c_phone_AT_ortsname_02914_tl} {Japons}
\tl_const:cn {c_phone_AT_ortsname_02915_tl} {Drosendorf-Zissersdorf}
\tl_const:cn {c_phone_AT_ortsname_02916_tl} {Riegersburg~(Hardegg)}
\tl_const:cn {c_phone_AT_ortsname_02942_tl} {Retz}
\tl_const:cn {c_phone_AT_ortsname_02943_tl} {Obritz}
\tl_const:cn {c_phone_AT_ortsname_02944_tl} {Haugsdorf}
\tl_const:cn {c_phone_AT_ortsname_02945_tl} {Zellerndorf}
\tl_const:cn {c_phone_AT_ortsname_02946_tl} {Pulkau}
\tl_const:cn {c_phone_AT_ortsname_02947_tl} {Theras}
\tl_const:cn {c_phone_AT_ortsname_02948_tl} {Weitersfeld}
\tl_const:cn {c_phone_AT_ortsname_02949_tl} {Niederfladnitz}
\tl_const:cn {c_phone_AT_ortsname_02951_tl} {Guntersdorf}
\tl_const:cn {c_phone_AT_ortsname_02952_tl} {Hollabrunn}
\tl_const:cn {c_phone_AT_ortsname_02953_tl} {Nappersdorf}
\tl_const:cn {c_phone_AT_ortsname_02954_tl} {G\"ollersdorf}
\tl_const:cn {c_phone_AT_ortsname_02955_tl} {Gro\ss weikersdorf}
\tl_const:cn {c_phone_AT_ortsname_02956_tl} {Ziersdorf}
\tl_const:cn {c_phone_AT_ortsname_02957_tl} {Hohenwarth-M\"uhlbach~am~Manhartsberg}
\tl_const:cn {c_phone_AT_ortsname_02958_tl} {Maissau}
\tl_const:cn {c_phone_AT_ortsname_02959_tl} {Sitzendorf~an~der~Schmida}
\tl_const:cn {c_phone_AT_ortsname_02982_tl} {Horn}
\tl_const:cn {c_phone_AT_ortsname_02983_tl} {Sigmundsherberg}
\tl_const:cn {c_phone_AT_ortsname_02984_tl} {Eggenburg}
\tl_const:cn {c_phone_AT_ortsname_02985_tl} {Gars~am~Kamp}
\tl_const:cn {c_phone_AT_ortsname_02986_tl} {Irnfritz}
\tl_const:cn {c_phone_AT_ortsname_02987_tl} {St.~Leonhard~am~Hornerwald}
\tl_const:cn {c_phone_AT_ortsname_02988_tl} {Neup\"olla}
\tl_const:cn {c_phone_AT_ortsname_02989_tl} {Brunn~an~der~Wild}
\tl_const:cn {c_phone_AT_ortsname_03112_tl} {Gleisdorf}
\tl_const:cn {c_phone_AT_ortsname_03113_tl} {Pischelsdorf~am~Kulm}
\tl_const:cn {c_phone_AT_ortsname_03114_tl} {Markt~Hartmannsdorf}
\tl_const:cn {c_phone_AT_ortsname_03115_tl} {Studenzen}
\tl_const:cn {c_phone_AT_ortsname_03116_tl} {Kirchbach-Zerlach}
\tl_const:cn {c_phone_AT_ortsname_03117_tl} {Eggersdorf~bei~Graz}
\tl_const:cn {c_phone_AT_ortsname_03118_tl} {Sinabelkirchen}
\tl_const:cn {c_phone_AT_ortsname_03119_tl} {Sankt~Marein~bei~Graz}
\tl_const:cn {c_phone_AT_ortsname_03123_tl} {Sankt~Oswald~bei~Plankenwarth}
\tl_const:cn {c_phone_AT_ortsname_03124_tl} {Gratkorn}
\tl_const:cn {c_phone_AT_ortsname_03125_tl} {\"Ubelbach}
\tl_const:cn {c_phone_AT_ortsname_03126_tl} {Frohnleiten}
\tl_const:cn {c_phone_AT_ortsname_03127_tl} {Peggau}
\tl_const:cn {c_phone_AT_ortsname_03132_tl} {Kumberg}
\tl_const:cn {c_phone_AT_ortsname_03133_tl} {Nestelbach}
\tl_const:cn {c_phone_AT_ortsname_03134_tl} {Heiligenkreuz~am~Waasen}
\tl_const:cn {c_phone_AT_ortsname_03135_tl} {Kalsdorf~bei~Graz}
\tl_const:cn {c_phone_AT_ortsname_03136_tl} {Dobl}
\tl_const:cn {c_phone_AT_ortsname_03137_tl} {S\"oding}
\tl_const:cn {c_phone_AT_ortsname_03140_tl} {Sankt~Martin~am~W\"ollmi\ss berg}
\tl_const:cn {c_phone_AT_ortsname_03141_tl} {Hirschegg}
\tl_const:cn {c_phone_AT_ortsname_03142_tl} {Voitsberg}
\tl_const:cn {c_phone_AT_ortsname_03143_tl} {Krottendorf-Gaisfeld}
\tl_const:cn {c_phone_AT_ortsname_03144_tl} {K\"of\/lach}
\tl_const:cn {c_phone_AT_ortsname_03145_tl} {Edelschrott}
\tl_const:cn {c_phone_AT_ortsname_03146_tl} {Modriach}
\tl_const:cn {c_phone_AT_ortsname_03147_tl} {Salla}
\tl_const:cn {c_phone_AT_ortsname_03148_tl} {Kainach~bei~Voitsberg}
\tl_const:cn {c_phone_AT_ortsname_03149_tl} {Geistthal}
\tl_const:cn {c_phone_AT_ortsname_03150_tl} {Paldau}
\tl_const:cn {c_phone_AT_ortsname_03151_tl} {Gnas}
\tl_const:cn {c_phone_AT_ortsname_03152_tl} {Feldbach}
\tl_const:cn {c_phone_AT_ortsname_03153_tl} {Riegersburg}
\tl_const:cn {c_phone_AT_ortsname_03155_tl} {Fehring}
\tl_const:cn {c_phone_AT_ortsname_03157_tl} {Kapfenstein}
\tl_const:cn {c_phone_AT_ortsname_03158_tl} {Sankt~Anna~am~Aigen}
\tl_const:cn {c_phone_AT_ortsname_03159_tl} {Bad~Gleichenberg}
\tl_const:cn {c_phone_AT_ortsname_0316_tl} {Graz}
\tl_const:cn {c_phone_AT_ortsname_03170_tl} {Fischbach}
\tl_const:cn {c_phone_AT_ortsname_03171_tl} {Gasen}
\tl_const:cn {c_phone_AT_ortsname_03172_tl} {Weiz}
\tl_const:cn {c_phone_AT_ortsname_03173_tl} {Ratten}
\tl_const:cn {c_phone_AT_ortsname_03174_tl} {Birkfeld}
\tl_const:cn {c_phone_AT_ortsname_03175_tl} {Anger}
\tl_const:cn {c_phone_AT_ortsname_03176_tl} {Stubenberg}
\tl_const:cn {c_phone_AT_ortsname_03177_tl} {Puch~bei~Weiz}
\tl_const:cn {c_phone_AT_ortsname_03178_tl} {Sankt~Ruprecht~an~der~Raab}
\tl_const:cn {c_phone_AT_ortsname_03179_tl} {Passail}
\tl_const:cn {c_phone_AT_ortsname_03182_tl} {Wildon}
\tl_const:cn {c_phone_AT_ortsname_03183_tl} {Sankt~Georgen~an~der~Stiefing}
\tl_const:cn {c_phone_AT_ortsname_03184_tl} {Wolfsberg~im~Schwarzautal}
\tl_const:cn {c_phone_AT_ortsname_03185_tl} {Preding}
\tl_const:cn {c_phone_AT_ortsname_03322_tl} {G\"ussing}
\tl_const:cn {c_phone_AT_ortsname_03323_tl} {Eberau}
\tl_const:cn {c_phone_AT_ortsname_03324_tl} {Strem}
\tl_const:cn {c_phone_AT_ortsname_03325_tl} {Heiligenkreuz~im~Lafnitztal}
\tl_const:cn {c_phone_AT_ortsname_03326_tl} {Stegersbach}
\tl_const:cn {c_phone_AT_ortsname_03327_tl} {Sankt~Michael~im~Burgenland}
\tl_const:cn {c_phone_AT_ortsname_03328_tl} {Kukmirn}
\tl_const:cn {c_phone_AT_ortsname_03329_tl} {Jennersdorf}
\tl_const:cn {c_phone_AT_ortsname_03331_tl} {Sankt~Lorenzen~am~Wechsel}
\tl_const:cn {c_phone_AT_ortsname_03332_tl} {Hartberg}
\tl_const:cn {c_phone_AT_ortsname_03333_tl} {Sebersdorf}
\tl_const:cn {c_phone_AT_ortsname_03334_tl} {Kaindorf}
\tl_const:cn {c_phone_AT_ortsname_03335_tl} {P\"ollau}
\tl_const:cn {c_phone_AT_ortsname_03336_tl} {Waldbach}
\tl_const:cn {c_phone_AT_ortsname_03337_tl} {Vorau}
\tl_const:cn {c_phone_AT_ortsname_03338_tl} {Lafnitz}
\tl_const:cn {c_phone_AT_ortsname_03339_tl} {Friedberg}
\tl_const:cn {c_phone_AT_ortsname_03352_tl} {Oberwart}
\tl_const:cn {c_phone_AT_ortsname_03353_tl} {Obersch\"utzen}
\tl_const:cn {c_phone_AT_ortsname_03354_tl} {Bernstein}
\tl_const:cn {c_phone_AT_ortsname_03355_tl} {Stadtschlaining}
\tl_const:cn {c_phone_AT_ortsname_03356_tl} {Markt~Allhau}
\tl_const:cn {c_phone_AT_ortsname_03357_tl} {Pinkafeld}
\tl_const:cn {c_phone_AT_ortsname_03358_tl} {Litzelsdorf}
\tl_const:cn {c_phone_AT_ortsname_03359_tl} {Loipersdorf-Kitzladen}
\tl_const:cn {c_phone_AT_ortsname_03362_tl} {Gro\ss petersdorf}
\tl_const:cn {c_phone_AT_ortsname_03363_tl} {Rechnitz}
\tl_const:cn {c_phone_AT_ortsname_03364_tl} {Hannersdorf}
\tl_const:cn {c_phone_AT_ortsname_03365_tl} {Deutsch~Sch\"utzen-Eisenberg}
\tl_const:cn {c_phone_AT_ortsname_03366_tl} {Kohfidisch}
\tl_const:cn {c_phone_AT_ortsname_03382_tl} {F\"urstenfeld}
\tl_const:cn {c_phone_AT_ortsname_03383_tl} {Burgau}
\tl_const:cn {c_phone_AT_ortsname_03385_tl} {Ilz}
\tl_const:cn {c_phone_AT_ortsname_03386_tl} {Gro\ss steinbach}
\tl_const:cn {c_phone_AT_ortsname_03387_tl} {S\"ochau}
\tl_const:cn {c_phone_AT_ortsname_03452_tl} {Leibnitz}
\tl_const:cn {c_phone_AT_ortsname_03453_tl} {Ehrenhausen}
\tl_const:cn {c_phone_AT_ortsname_03454_tl} {Leutschach}
\tl_const:cn {c_phone_AT_ortsname_03455_tl} {Arnfels}
\tl_const:cn {c_phone_AT_ortsname_03456_tl} {Fresing}
\tl_const:cn {c_phone_AT_ortsname_03457_tl} {Gleinst\"atten}
\tl_const:cn {c_phone_AT_ortsname_03460_tl} {Soboth}
\tl_const:cn {c_phone_AT_ortsname_03461_tl} {Trah\"utten}
\tl_const:cn {c_phone_AT_ortsname_03462_tl} {Deutschlandsberg}
\tl_const:cn {c_phone_AT_ortsname_03463_tl} {Stainz}
\tl_const:cn {c_phone_AT_ortsname_03464_tl} {Gro\ss\ Sankt~Florian}
\tl_const:cn {c_phone_AT_ortsname_03465_tl} {P\"olfing-Brunn}
\tl_const:cn {c_phone_AT_ortsname_03466_tl} {Eibiswald}
\tl_const:cn {c_phone_AT_ortsname_03467_tl} {Bad~Schwanberg}
\tl_const:cn {c_phone_AT_ortsname_03468_tl} {Sankt~Oswald~ob~Eibiswald}
\tl_const:cn {c_phone_AT_ortsname_03469_tl} {Sankt~Oswald~in~Freiland}
\tl_const:cn {c_phone_AT_ortsname_03472_tl} {Mureck}
\tl_const:cn {c_phone_AT_ortsname_03473_tl} {Straden}
\tl_const:cn {c_phone_AT_ortsname_03474_tl} {Deutsch~Goritz}
\tl_const:cn {c_phone_AT_ortsname_03475_tl} {H\"urth}
\tl_const:cn {c_phone_AT_ortsname_03476_tl} {Bad~Radkersburg}
\tl_const:cn {c_phone_AT_ortsname_03477_tl} {Sankt~Peter~am~Ottersbach}
\tl_const:cn {c_phone_AT_ortsname_03512_tl} {Knittelfeld}
\tl_const:cn {c_phone_AT_ortsname_03513_tl} {Bischof\/feld}
\tl_const:cn {c_phone_AT_ortsname_03514_tl} {Seckau}
\tl_const:cn {c_phone_AT_ortsname_03515_tl} {Sankt~Lorenzen~bei~Knittelfeld}
\tl_const:cn {c_phone_AT_ortsname_03516_tl} {Kleinlobming}
\tl_const:cn {c_phone_AT_ortsname_03532_tl} {Murau}
\tl_const:cn {c_phone_AT_ortsname_03533_tl} {Turrach}
\tl_const:cn {c_phone_AT_ortsname_03534_tl} {Stadl~an~der~Mur}
\tl_const:cn {c_phone_AT_ortsname_03535_tl} {Krakaudorf}
\tl_const:cn {c_phone_AT_ortsname_03536_tl} {St.~Peter~am~Kammersberg}
\tl_const:cn {c_phone_AT_ortsname_03537_tl} {Sankt~Georgen~ob~Murau}
\tl_const:cn {c_phone_AT_ortsname_03571_tl} {M\"oderbrugg}
\tl_const:cn {c_phone_AT_ortsname_03572_tl} {Judenburg}
\tl_const:cn {c_phone_AT_ortsname_03573_tl} {Fohnsdorf}
\tl_const:cn {c_phone_AT_ortsname_03574_tl} {Pusterwald}
\tl_const:cn {c_phone_AT_ortsname_03575_tl} {Sankt~Johann~am~Tauern}
\tl_const:cn {c_phone_AT_ortsname_03576_tl} {Bretstein}
\tl_const:cn {c_phone_AT_ortsname_03577_tl} {Zeltweg}
\tl_const:cn {c_phone_AT_ortsname_03578_tl} {Obdach}
\tl_const:cn {c_phone_AT_ortsname_03579_tl} {P\"ols}
\tl_const:cn {c_phone_AT_ortsname_03581_tl} {Oberw\"olz}
\tl_const:cn {c_phone_AT_ortsname_03582_tl} {Scheif\/ling}
\tl_const:cn {c_phone_AT_ortsname_03583_tl} {Unzmarkt-Frauenburg}
\tl_const:cn {c_phone_AT_ortsname_03584_tl} {Neumarkt~in~der~Steiermark}
\tl_const:cn {c_phone_AT_ortsname_03585_tl} {Sankt~Lambrecht}
\tl_const:cn {c_phone_AT_ortsname_03586_tl} {M\"uhlen}
\tl_const:cn {c_phone_AT_ortsname_03587_tl} {Sch\"onberg-Lachtal}
\tl_const:cn {c_phone_AT_ortsname_03588_tl} {Katsch~an~der~Mur}
\tl_const:cn {c_phone_AT_ortsname_03611_tl} {Johnsbach}
\tl_const:cn {c_phone_AT_ortsname_03612_tl} {Liezen}
\tl_const:cn {c_phone_AT_ortsname_03613_tl} {Admont}
\tl_const:cn {c_phone_AT_ortsname_03614_tl} {Rottenmann}
\tl_const:cn {c_phone_AT_ortsname_03615_tl} {Trieben}
\tl_const:cn {c_phone_AT_ortsname_03616_tl} {Selzthal}
\tl_const:cn {c_phone_AT_ortsname_03617_tl} {Gaishorn~am~See}
\tl_const:cn {c_phone_AT_ortsname_03618_tl} {Hohentauern}
\tl_const:cn {c_phone_AT_ortsname_03619_tl} {Oppenberg}
\tl_const:cn {c_phone_AT_ortsname_03622_tl} {Bad~Aussee}
\tl_const:cn {c_phone_AT_ortsname_03623_tl} {Bad~Mitterndorf}
\tl_const:cn {c_phone_AT_ortsname_03624_tl} {Pichl-Kainisch}
\tl_const:cn {c_phone_AT_ortsname_03631_tl} {Unterlaussa}
\tl_const:cn {c_phone_AT_ortsname_03632_tl} {Sankt~Gallen}
\tl_const:cn {c_phone_AT_ortsname_03633_tl} {Landl}
\tl_const:cn {c_phone_AT_ortsname_03634_tl} {Hieflau}
\tl_const:cn {c_phone_AT_ortsname_03635_tl} {Radmer}
\tl_const:cn {c_phone_AT_ortsname_03636_tl} {Wildalpen}
\tl_const:cn {c_phone_AT_ortsname_03637_tl} {Gams~bei~Hieflau}
\tl_const:cn {c_phone_AT_ortsname_03638_tl} {Palfau}
\tl_const:cn {c_phone_AT_ortsname_03680_tl} {Donnersbachwald}
\tl_const:cn {c_phone_AT_ortsname_03682_tl} {Stainach}
\tl_const:cn {c_phone_AT_ortsname_03683_tl} {Donnersbach}
\tl_const:cn {c_phone_AT_ortsname_03684_tl} {Sankt~Martin~am~Grimming}
\tl_const:cn {c_phone_AT_ortsname_03685_tl} {Gr\"obming}
\tl_const:cn {c_phone_AT_ortsname_03686_tl} {Haus}
\tl_const:cn {c_phone_AT_ortsname_03687_tl} {Schladming}
\tl_const:cn {c_phone_AT_ortsname_03688_tl} {Tauplitz}
\tl_const:cn {c_phone_AT_ortsname_03689_tl} {Sankt~Nikolai~im~S\"olktal}
\tl_const:cn {c_phone_AT_ortsname_03832_tl} {Kraubath~an~der~Mur}
\tl_const:cn {c_phone_AT_ortsname_03833_tl} {Traboch}
\tl_const:cn {c_phone_AT_ortsname_03834_tl} {Wald~am~Schoberpa\ss}
\tl_const:cn {c_phone_AT_ortsname_03842_tl} {Leoben}
\tl_const:cn {c_phone_AT_ortsname_03843_tl} {Sankt~Michael~in~Obersteiermark}
\tl_const:cn {c_phone_AT_ortsname_03844_tl} {Kammern~im~Liesingtal}
\tl_const:cn {c_phone_AT_ortsname_03845_tl} {Mautern~in~Steiermark}
\tl_const:cn {c_phone_AT_ortsname_03846_tl} {Kalwang}
\tl_const:cn {c_phone_AT_ortsname_03847_tl} {Trofaiach}
\tl_const:cn {c_phone_AT_ortsname_03848_tl} {Eisenerz}
\tl_const:cn {c_phone_AT_ortsname_03849_tl} {Vordernberg}
\tl_const:cn {c_phone_AT_ortsname_03852_tl} {M\"urzzuschlag}
\tl_const:cn {c_phone_AT_ortsname_03853_tl} {Spital~am~Semmering}
\tl_const:cn {c_phone_AT_ortsname_03854_tl} {Langenwang}
\tl_const:cn {c_phone_AT_ortsname_03855_tl} {Krieglach}
\tl_const:cn {c_phone_AT_ortsname_03856_tl} {Veitsch}
\tl_const:cn {c_phone_AT_ortsname_03857_tl} {Neuberg~an~der~M\"urz}
\tl_const:cn {c_phone_AT_ortsname_03858_tl} {Mitterdorf~im~M\"urztal}
\tl_const:cn {c_phone_AT_ortsname_03859_tl} {M\"urzsteg}
\tl_const:cn {c_phone_AT_ortsname_03861_tl} {Aflenz}
\tl_const:cn {c_phone_AT_ortsname_03862_tl} {Bruck~an~der~Mur}
\tl_const:cn {c_phone_AT_ortsname_03863_tl} {Turnau}
\tl_const:cn {c_phone_AT_ortsname_03864_tl} {Sankt~Marein~im~M\"urztal}
\tl_const:cn {c_phone_AT_ortsname_03865_tl} {Kindberg}
\tl_const:cn {c_phone_AT_ortsname_03866_tl} {Breitenau~am~Hochlantsch}
\tl_const:cn {c_phone_AT_ortsname_03867_tl} {Pernegg~an~der~Mur}
\tl_const:cn {c_phone_AT_ortsname_03868_tl} {Trag\"o\ss}
\tl_const:cn {c_phone_AT_ortsname_03869_tl} {Sankt~Katharein~an~der~Laming}
\tl_const:cn {c_phone_AT_ortsname_03882_tl} {Mariazell}
\tl_const:cn {c_phone_AT_ortsname_03883_tl} {Terz}
\tl_const:cn {c_phone_AT_ortsname_03884_tl} {Wegscheid}
\tl_const:cn {c_phone_AT_ortsname_03885_tl} {Greith~(Mariazell)}
\tl_const:cn {c_phone_AT_ortsname_03886_tl} {Weichselboden}
\tl_const:cn {c_phone_AT_ortsname_04212_tl} {St.~Veit~an~der~Glan}
\tl_const:cn {c_phone_AT_ortsname_04213_tl} {Launsdorf}
\tl_const:cn {c_phone_AT_ortsname_04214_tl} {Br\"uckl}
\tl_const:cn {c_phone_AT_ortsname_04215_tl} {Liebenfels}
\tl_const:cn {c_phone_AT_ortsname_04220_tl} {K\"ottmannsdorf}
\tl_const:cn {c_phone_AT_ortsname_04221_tl} {Gallizien}
\tl_const:cn {c_phone_AT_ortsname_04223_tl} {Maria~Saal}
\tl_const:cn {c_phone_AT_ortsname_04224_tl} {Pischeldorf}
\tl_const:cn {c_phone_AT_ortsname_04225_tl} {Grafenstein}
\tl_const:cn {c_phone_AT_ortsname_04226_tl} {St.~Margareten~im~Rosental}
\tl_const:cn {c_phone_AT_ortsname_04227_tl} {Ferlach}
\tl_const:cn {c_phone_AT_ortsname_04228_tl} {Feistritz~im~Rosental}
\tl_const:cn {c_phone_AT_ortsname_04229_tl} {Krumpendorf~am~W\"orthersee}
\tl_const:cn {c_phone_AT_ortsname_04230_tl} {Globasnitz}
\tl_const:cn {c_phone_AT_ortsname_04231_tl} {Mittertrixen}
\tl_const:cn {c_phone_AT_ortsname_04232_tl} {V\"olkermarkt}
\tl_const:cn {c_phone_AT_ortsname_04233_tl} {Griffen}
\tl_const:cn {c_phone_AT_ortsname_04234_tl} {Ruden}
\tl_const:cn {c_phone_AT_ortsname_04235_tl} {Bleiburg}
\tl_const:cn {c_phone_AT_ortsname_04236_tl} {Eberndorf}
\tl_const:cn {c_phone_AT_ortsname_04237_tl} {Miklauzhof}
\tl_const:cn {c_phone_AT_ortsname_04238_tl} {Eisenkappel-Vellach}
\tl_const:cn {c_phone_AT_ortsname_04239_tl} {St.~Kanzian~am~Klopeiner~See}
\tl_const:cn {c_phone_AT_ortsname_04240_tl} {Bad~Kleinkirchheim}
\tl_const:cn {c_phone_AT_ortsname_04242_tl} {Villach}
\tl_const:cn {c_phone_AT_ortsname_04243_tl} {Bodensdorf}
\tl_const:cn {c_phone_AT_ortsname_04244_tl} {Bad~Bleiberg}
\tl_const:cn {c_phone_AT_ortsname_04245_tl} {Feistritz~an~der~Drau}
\tl_const:cn {c_phone_AT_ortsname_04246_tl} {Radenthein}
\tl_const:cn {c_phone_AT_ortsname_04247_tl} {Afritz}
\tl_const:cn {c_phone_AT_ortsname_04248_tl} {Treffen}
\tl_const:cn {c_phone_AT_ortsname_04252_tl} {Wernberg}
\tl_const:cn {c_phone_AT_ortsname_04253_tl} {St.~Jakob~im~Rosental}
\tl_const:cn {c_phone_AT_ortsname_04254_tl} {Faak~am~See}
\tl_const:cn {c_phone_AT_ortsname_04255_tl} {Arnoldstein}
\tl_const:cn {c_phone_AT_ortsname_04256_tl} {N\"otsch~im~Gailtal}
\tl_const:cn {c_phone_AT_ortsname_04257_tl} {F\"urnitz}
\tl_const:cn {c_phone_AT_ortsname_04258_tl} {Gummern}
\tl_const:cn {c_phone_AT_ortsname_04262_tl} {Treibach}
\tl_const:cn {c_phone_AT_ortsname_04263_tl} {H\"uttenberg}
\tl_const:cn {c_phone_AT_ortsname_04264_tl} {Klein~St.~Paul}
\tl_const:cn {c_phone_AT_ortsname_04265_tl} {Weitensfeld~im~Gurktal}
\tl_const:cn {c_phone_AT_ortsname_04266_tl} {Stra\ss burg}
\tl_const:cn {c_phone_AT_ortsname_04267_tl} {Metnitz}
\tl_const:cn {c_phone_AT_ortsname_04268_tl} {Friesach}
\tl_const:cn {c_phone_AT_ortsname_04269_tl} {Flattnitz}
\tl_const:cn {c_phone_AT_ortsname_04271_tl} {Steuerberg}
\tl_const:cn {c_phone_AT_ortsname_04272_tl} {P\"ortschach~am~W\"orther~See}
\tl_const:cn {c_phone_AT_ortsname_04273_tl} {Reifnitz}
\tl_const:cn {c_phone_AT_ortsname_04274_tl} {Velden~am~W\"orther~See}
\tl_const:cn {c_phone_AT_ortsname_04275_tl} {Ebene~Reichenau}
\tl_const:cn {c_phone_AT_ortsname_04276_tl} {Feldkirchen~in~K\"arnten}
\tl_const:cn {c_phone_AT_ortsname_04277_tl} {Glanegg}
\tl_const:cn {c_phone_AT_ortsname_04278_tl} {Gnesau}
\tl_const:cn {c_phone_AT_ortsname_04279_tl} {Sirnitz}
\tl_const:cn {c_phone_AT_ortsname_04282_tl} {Hermagor}
\tl_const:cn {c_phone_AT_ortsname_04283_tl} {St.~Stefan~im~Gailtal}
\tl_const:cn {c_phone_AT_ortsname_04284_tl} {Kirchbach~(K\"arnten)}
\tl_const:cn {c_phone_AT_ortsname_04285_tl} {Tr\"opolach}
\tl_const:cn {c_phone_AT_ortsname_04286_tl} {Wei\ss briach}
\tl_const:cn {c_phone_AT_ortsname_04350_tl} {Bad~St.~Leonhard~im~Lavanttal}
\tl_const:cn {c_phone_AT_ortsname_04352_tl} {Wolfsberg}
\tl_const:cn {c_phone_AT_ortsname_04353_tl} {Prebl}
\tl_const:cn {c_phone_AT_ortsname_04354_tl} {Preitenegg}
\tl_const:cn {c_phone_AT_ortsname_04355_tl} {Gemmersdorf}
\tl_const:cn {c_phone_AT_ortsname_04356_tl} {Lavam\"und}
\tl_const:cn {c_phone_AT_ortsname_04357_tl} {St.~Paul~im~Lavanttal}
\tl_const:cn {c_phone_AT_ortsname_04358_tl} {St.~Andr\"a}
\tl_const:cn {c_phone_AT_ortsname_04359_tl} {Reichenfels}
\tl_const:cn {c_phone_AT_ortsname_0463_tl} {Klagenfurt}
\tl_const:cn {c_phone_AT_ortsname_04710_tl} {Oberdrauburg}
\tl_const:cn {c_phone_AT_ortsname_04712_tl} {Greifenburg}
\tl_const:cn {c_phone_AT_ortsname_04713_tl} {Techendorf}
\tl_const:cn {c_phone_AT_ortsname_04714_tl} {Dellach~im~Drautal}
\tl_const:cn {c_phone_AT_ortsname_04715_tl} {K\"otschach-Mauthen}
\tl_const:cn {c_phone_AT_ortsname_04716_tl} {Lesachtal}
\tl_const:cn {c_phone_AT_ortsname_04717_tl} {Steinfeld}
\tl_const:cn {c_phone_AT_ortsname_04718_tl} {Dellach}
\tl_const:cn {c_phone_AT_ortsname_04732_tl} {Gm\"und~in~K\"arnten}
\tl_const:cn {c_phone_AT_ortsname_04733_tl} {Malta}
\tl_const:cn {c_phone_AT_ortsname_04734_tl} {Rennweg}
\tl_const:cn {c_phone_AT_ortsname_04735_tl} {Kremsbr\"ucke}
\tl_const:cn {c_phone_AT_ortsname_04736_tl} {Innerkrems}
\tl_const:cn {c_phone_AT_ortsname_04761_tl} {Stockenboi}
\tl_const:cn {c_phone_AT_ortsname_04762_tl} {Spittal~an~der~Drau}
\tl_const:cn {c_phone_AT_ortsname_04766_tl} {Millstatt~am~See}
\tl_const:cn {c_phone_AT_ortsname_04767_tl} {Rothenthurn}
\tl_const:cn {c_phone_AT_ortsname_04768_tl} {Kleblach-Lind}
\tl_const:cn {c_phone_AT_ortsname_04769_tl} {M\"ollbr\"ucke}
\tl_const:cn {c_phone_AT_ortsname_04782_tl} {Obervellach}
\tl_const:cn {c_phone_AT_ortsname_04783_tl} {Rei\ss eck}
\tl_const:cn {c_phone_AT_ortsname_04784_tl} {Mallnitz}
\tl_const:cn {c_phone_AT_ortsname_04785_tl} {Au\ss erfragant}
\tl_const:cn {c_phone_AT_ortsname_04822_tl} {Winklern}
\tl_const:cn {c_phone_AT_ortsname_04823_tl} {Tresdorf~(Rangersdorf)}
\tl_const:cn {c_phone_AT_ortsname_04824_tl} {Heiligenblut~am~Gro\ss glockner}
\tl_const:cn {c_phone_AT_ortsname_04825_tl} {Gro\ss kirchheim}
\tl_const:cn {c_phone_AT_ortsname_04826_tl} {M\"ortschach}
\tl_const:cn {c_phone_AT_ortsname_04842_tl} {Sillian}
\tl_const:cn {c_phone_AT_ortsname_04843_tl} {Au\ss ervillgraten}
\tl_const:cn {c_phone_AT_ortsname_04846_tl} {Abfaltersbach}
\tl_const:cn {c_phone_AT_ortsname_04847_tl} {Obertilliach}
\tl_const:cn {c_phone_AT_ortsname_04848_tl} {Kartitsch}
\tl_const:cn {c_phone_AT_ortsname_04852_tl} {Lienz}
\tl_const:cn {c_phone_AT_ortsname_04853_tl} {Ainet}
\tl_const:cn {c_phone_AT_ortsname_04855_tl} {Assling}
\tl_const:cn {c_phone_AT_ortsname_04858_tl} {Nikolsdorf}
\tl_const:cn {c_phone_AT_ortsname_04872_tl} {Huben}
\tl_const:cn {c_phone_AT_ortsname_04873_tl} {St.~Jakob~in~Defereggen}
\tl_const:cn {c_phone_AT_ortsname_04874_tl} {Virgen}
\tl_const:cn {c_phone_AT_ortsname_04875_tl} {Matrei~in~Osttirol}
\tl_const:cn {c_phone_AT_ortsname_04876_tl} {Kals~am~Gro\ss glockner}
\tl_const:cn {c_phone_AT_ortsname_04877_tl} {Pr\"agraten~am~Gro\ss venediger}
\tl_const:cn {c_phone_AT_ortsname_04879_tl} {St.~Veit~in~Defereggen}
\tl_const:cn {c_phone_AT_ortsname_0512_tl} {Innsbruck}
\tl_const:cn {c_phone_AT_ortsname_05212_tl} {Seefeld~in~Tirol}
\tl_const:cn {c_phone_AT_ortsname_05213_tl} {Scharnitz}
\tl_const:cn {c_phone_AT_ortsname_05214_tl} {Leutasch}
\tl_const:cn {c_phone_AT_ortsname_05223_tl} {Hall~in~Tirol}
\tl_const:cn {c_phone_AT_ortsname_05224_tl} {Wattens}
\tl_const:cn {c_phone_AT_ortsname_05225_tl} {Fulpmes}
\tl_const:cn {c_phone_AT_ortsname_05226_tl} {Neustift~im~Stubaital}
\tl_const:cn {c_phone_AT_ortsname_05230_tl} {Sellrain}
\tl_const:cn {c_phone_AT_ortsname_05232_tl} {Kematen~in~Tirol}
\tl_const:cn {c_phone_AT_ortsname_05234_tl} {Axams}
\tl_const:cn {c_phone_AT_ortsname_05236_tl} {Gries~im~Sellrain}
\tl_const:cn {c_phone_AT_ortsname_05238_tl} {Zirl}
\tl_const:cn {c_phone_AT_ortsname_05239_tl} {K\"uhtai}
\tl_const:cn {c_phone_AT_ortsname_05242_tl} {Schwaz}
\tl_const:cn {c_phone_AT_ortsname_05243_tl} {Maurach}
\tl_const:cn {c_phone_AT_ortsname_05244_tl} {Jenbach}
\tl_const:cn {c_phone_AT_ortsname_05245_tl} {Hinterri\ss}
\tl_const:cn {c_phone_AT_ortsname_05246_tl} {Achenkirch}
\tl_const:cn {c_phone_AT_ortsname_05248_tl} {Steinberg~am~Rofan}
\tl_const:cn {c_phone_AT_ortsname_05252_tl} {Oetz}
\tl_const:cn {c_phone_AT_ortsname_05253_tl} {L\"angenfeld}
\tl_const:cn {c_phone_AT_ortsname_05254_tl} {S\"olden}
\tl_const:cn {c_phone_AT_ortsname_05255_tl} {Umhausen}
\tl_const:cn {c_phone_AT_ortsname_05256_tl} {Untergurgl}
\tl_const:cn {c_phone_AT_ortsname_05262_tl} {Telfs}
\tl_const:cn {c_phone_AT_ortsname_05263_tl} {Silz}
\tl_const:cn {c_phone_AT_ortsname_05264_tl} {Mieming}
\tl_const:cn {c_phone_AT_ortsname_05265_tl} {Nassereith}
\tl_const:cn {c_phone_AT_ortsname_05266_tl} {\"Otztal-Bahnhof}
\tl_const:cn {c_phone_AT_ortsname_05272_tl} {Steinach~am~Brenner}
\tl_const:cn {c_phone_AT_ortsname_05273_tl} {Matrei~am~Brenner}
\tl_const:cn {c_phone_AT_ortsname_05274_tl} {Gries~am~Brenner}
\tl_const:cn {c_phone_AT_ortsname_05275_tl} {Trins}
\tl_const:cn {c_phone_AT_ortsname_05276_tl} {Gschnitz}
\tl_const:cn {c_phone_AT_ortsname_05278_tl} {Navis}
\tl_const:cn {c_phone_AT_ortsname_05279_tl} {St.~Jodok~am~Brenner}
\tl_const:cn {c_phone_AT_ortsname_05280_tl} {Hochf\"ugen}
\tl_const:cn {c_phone_AT_ortsname_05282_tl} {Zell~am~Ziller}
\tl_const:cn {c_phone_AT_ortsname_05283_tl} {Kaltenbach~(Tirol)}
\tl_const:cn {c_phone_AT_ortsname_05284_tl} {Gerlos}
\tl_const:cn {c_phone_AT_ortsname_05285_tl} {Mayrhofen}
\tl_const:cn {c_phone_AT_ortsname_05286_tl} {Ginzling}
\tl_const:cn {c_phone_AT_ortsname_05287_tl} {Tux}
\tl_const:cn {c_phone_AT_ortsname_05288_tl} {F\"ugen}
\tl_const:cn {c_phone_AT_ortsname_05289_tl} {H\"ausling}
\tl_const:cn {c_phone_AT_ortsname_05331_tl} {Brandenberg}
\tl_const:cn {c_phone_AT_ortsname_05332_tl} {W\"orgl}
\tl_const:cn {c_phone_AT_ortsname_05333_tl} {S\"oll~(Tirol)}
\tl_const:cn {c_phone_AT_ortsname_05334_tl} {Westendorf}
\tl_const:cn {c_phone_AT_ortsname_05335_tl} {Hopfgarten~im~Brixental}
\tl_const:cn {c_phone_AT_ortsname_05336_tl} {Alpbach}
\tl_const:cn {c_phone_AT_ortsname_05337_tl} {Brixlegg}
\tl_const:cn {c_phone_AT_ortsname_05338_tl} {Kundl}
\tl_const:cn {c_phone_AT_ortsname_05339_tl} {Wildsch\"onau}
\tl_const:cn {c_phone_AT_ortsname_05352_tl} {St.~Johann~in~Tirol}
\tl_const:cn {c_phone_AT_ortsname_05353_tl} {Waidring}
\tl_const:cn {c_phone_AT_ortsname_05354_tl} {Fieberbrunn}
\tl_const:cn {c_phone_AT_ortsname_05355_tl} {Jochberg}
\tl_const:cn {c_phone_AT_ortsname_05356_tl} {Kitzb\"uhel}
\tl_const:cn {c_phone_AT_ortsname_05357_tl} {Kirchberg~in~Tirol}
\tl_const:cn {c_phone_AT_ortsname_05358_tl} {Ellmau}
\tl_const:cn {c_phone_AT_ortsname_05359_tl} {Hochfilzen}
\tl_const:cn {c_phone_AT_ortsname_05372_tl} {Kufstein}
\tl_const:cn {c_phone_AT_ortsname_05373_tl} {Ebbs}
\tl_const:cn {c_phone_AT_ortsname_05374_tl} {Walchsee}
\tl_const:cn {c_phone_AT_ortsname_05375_tl} {K\"ossen}
\tl_const:cn {c_phone_AT_ortsname_05376_tl} {Thiersee}
\tl_const:cn {c_phone_AT_ortsname_05412_tl} {Imst}
\tl_const:cn {c_phone_AT_ortsname_05413_tl} {St.~Leonhard~im~Pitztal}
\tl_const:cn {c_phone_AT_ortsname_05414_tl} {Wenns}
\tl_const:cn {c_phone_AT_ortsname_05417_tl} {Roppen}
\tl_const:cn {c_phone_AT_ortsname_05418_tl} {Sch\"onwies}
\tl_const:cn {c_phone_AT_ortsname_05441_tl} {See}
\tl_const:cn {c_phone_AT_ortsname_05442_tl} {Landeck}
\tl_const:cn {c_phone_AT_ortsname_05443_tl} {Galt\"ur}
\tl_const:cn {c_phone_AT_ortsname_05444_tl} {Ischgl}
\tl_const:cn {c_phone_AT_ortsname_05445_tl} {Kappl}
\tl_const:cn {c_phone_AT_ortsname_05446_tl} {St.~Anton~am~Arlberg}
\tl_const:cn {c_phone_AT_ortsname_05447_tl} {Flirsch}
\tl_const:cn {c_phone_AT_ortsname_05448_tl} {Pettneu~am~Arlberg}
\tl_const:cn {c_phone_AT_ortsname_05449_tl} {Flie\ss}
\tl_const:cn {c_phone_AT_ortsname_05472_tl} {Prutz}
\tl_const:cn {c_phone_AT_ortsname_05473_tl} {Nauders}
\tl_const:cn {c_phone_AT_ortsname_05474_tl} {Pfunds}
\tl_const:cn {c_phone_AT_ortsname_05475_tl} {Feichten}
\tl_const:cn {c_phone_AT_ortsname_05476_tl} {Serfaus}
\tl_const:cn {c_phone_AT_ortsname_05477_tl} {T\"osens}
\tl_const:cn {c_phone_AT_ortsname_05510_tl} {Dam\"uls}
\tl_const:cn {c_phone_AT_ortsname_05512_tl} {Egg}
\tl_const:cn {c_phone_AT_ortsname_05513_tl} {Hittisau}
\tl_const:cn {c_phone_AT_ortsname_05514_tl} {Bezau}
\tl_const:cn {c_phone_AT_ortsname_05515_tl} {Au}
\tl_const:cn {c_phone_AT_ortsname_05516_tl} {Doren}
\tl_const:cn {c_phone_AT_ortsname_05517_tl} {Riezlern}
\tl_const:cn {c_phone_AT_ortsname_05518_tl} {Mellau}
\tl_const:cn {c_phone_AT_ortsname_05519_tl} {Schr\"ocken}
\tl_const:cn {c_phone_AT_ortsname_05522_tl} {Feldkirch}
\tl_const:cn {c_phone_AT_ortsname_05523_tl} {G\"otzis}
\tl_const:cn {c_phone_AT_ortsname_05524_tl} {Satteins}
\tl_const:cn {c_phone_AT_ortsname_05525_tl} {Nenzing}
\tl_const:cn {c_phone_AT_ortsname_05526_tl} {Laterns}
\tl_const:cn {c_phone_AT_ortsname_05550_tl} {Th\"uringen}
\tl_const:cn {c_phone_AT_ortsname_05552_tl} {Bludenz}
\tl_const:cn {c_phone_AT_ortsname_05553_tl} {Raggal}
\tl_const:cn {c_phone_AT_ortsname_05554_tl} {Sonntag}
\tl_const:cn {c_phone_AT_ortsname_05556_tl} {Schruns}
\tl_const:cn {c_phone_AT_ortsname_05557_tl} {St.~Gallenkirch}
\tl_const:cn {c_phone_AT_ortsname_05558_tl} {Gaschurn}
\tl_const:cn {c_phone_AT_ortsname_05559_tl} {Brand}
\tl_const:cn {c_phone_AT_ortsname_05572_tl} {Dornbirn}
\tl_const:cn {c_phone_AT_ortsname_05573_tl} {H\"orbranz}
\tl_const:cn {c_phone_AT_ortsname_05574_tl} {Bregenz}
\tl_const:cn {c_phone_AT_ortsname_05575_tl} {Langen~bei~Bregenz}
\tl_const:cn {c_phone_AT_ortsname_05576_tl} {Hohenems}
\tl_const:cn {c_phone_AT_ortsname_05577_tl} {Lustenau}
\tl_const:cn {c_phone_AT_ortsname_05578_tl} {H\"ochst}
\tl_const:cn {c_phone_AT_ortsname_05579_tl} {Alberschwende}
\tl_const:cn {c_phone_AT_ortsname_05582_tl} {Kl\"osterle}
\tl_const:cn {c_phone_AT_ortsname_05583_tl} {Lech}
\tl_const:cn {c_phone_AT_ortsname_05585_tl} {Dalaas}
\tl_const:cn {c_phone_AT_ortsname_05632_tl} {Stanzach}
\tl_const:cn {c_phone_AT_ortsname_05633_tl} {H\"agerau}
\tl_const:cn {c_phone_AT_ortsname_05634_tl} {Elbigenalp}
\tl_const:cn {c_phone_AT_ortsname_05635_tl} {Elmen}
\tl_const:cn {c_phone_AT_ortsname_05672_tl} {Reutte}
\tl_const:cn {c_phone_AT_ortsname_05673_tl} {Ehrwald}
\tl_const:cn {c_phone_AT_ortsname_05674_tl} {Bichlbach}
\tl_const:cn {c_phone_AT_ortsname_05675_tl} {Tannheim}
\tl_const:cn {c_phone_AT_ortsname_05676_tl} {Jungholz}
\tl_const:cn {c_phone_AT_ortsname_05677_tl} {Vils~(Tirol)}
\tl_const:cn {c_phone_AT_ortsname_05678_tl} {Wei\ss enbach~am~Lech}
\tl_const:cn {c_phone_AT_ortsname_06131_tl} {Obertraun}
\tl_const:cn {c_phone_AT_ortsname_06132_tl} {Bad~Ischl}
\tl_const:cn {c_phone_AT_ortsname_06133_tl} {Ebensee}
\tl_const:cn {c_phone_AT_ortsname_06134_tl} {Hallstatt}
\tl_const:cn {c_phone_AT_ortsname_06135_tl} {Bad~Goisern}
\tl_const:cn {c_phone_AT_ortsname_06136_tl} {Gosau}
\tl_const:cn {c_phone_AT_ortsname_06137_tl} {Strobl}
\tl_const:cn {c_phone_AT_ortsname_06138_tl} {St.~Wolfgang~im~Salzkammergut}
\tl_const:cn {c_phone_AT_ortsname_06212_tl} {Seekirchen~am~Wallersee}
\tl_const:cn {c_phone_AT_ortsname_06213_tl} {Oberhofen~am~Irrsee}
\tl_const:cn {c_phone_AT_ortsname_06214_tl} {Henndorf~am~Wallersee}
\tl_const:cn {c_phone_AT_ortsname_06215_tl} {Stra\ss walchen}
\tl_const:cn {c_phone_AT_ortsname_06216_tl} {Neumarkt~am~Wallersee}
\tl_const:cn {c_phone_AT_ortsname_06217_tl} {Mattsee}
\tl_const:cn {c_phone_AT_ortsname_06219_tl} {Obertrum~am~See}
\tl_const:cn {c_phone_AT_ortsname_06221_tl} {Koppl}
\tl_const:cn {c_phone_AT_ortsname_06223_tl} {Anthering}
\tl_const:cn {c_phone_AT_ortsname_06224_tl} {Hintersee}
\tl_const:cn {c_phone_AT_ortsname_06225_tl} {Eugendorf}
\tl_const:cn {c_phone_AT_ortsname_06226_tl} {Fuschl~am~See}
\tl_const:cn {c_phone_AT_ortsname_06227_tl} {Sankt~Gilgen}
\tl_const:cn {c_phone_AT_ortsname_06228_tl} {Faistenau}
\tl_const:cn {c_phone_AT_ortsname_06229_tl} {Hof~bei~Salzburg}
\tl_const:cn {c_phone_AT_ortsname_06232_tl} {Mondsee}
\tl_const:cn {c_phone_AT_ortsname_06233_tl} {Oberwang}
\tl_const:cn {c_phone_AT_ortsname_06234_tl} {Zell~am~Moos}
\tl_const:cn {c_phone_AT_ortsname_06235_tl} {Thalgau}
\tl_const:cn {c_phone_AT_ortsname_06240_tl} {Krispl}
\tl_const:cn {c_phone_AT_ortsname_06241_tl} {Sankt~Koloman}
\tl_const:cn {c_phone_AT_ortsname_06242_tl} {Ru\ss bach~am~Pa\ss\ Gsch\"utt}
\tl_const:cn {c_phone_AT_ortsname_06243_tl} {Abtenau}
\tl_const:cn {c_phone_AT_ortsname_06244_tl} {Golling~an~der~Salzach}
\tl_const:cn {c_phone_AT_ortsname_06245_tl} {Hallein}
\tl_const:cn {c_phone_AT_ortsname_06246_tl} {Gr\"odig}
\tl_const:cn {c_phone_AT_ortsname_06247_tl} {Gro\ss gmain}
\tl_const:cn {c_phone_AT_ortsname_06272_tl} {Oberndorf~bei~Salzburg}
\tl_const:cn {c_phone_AT_ortsname_06274_tl} {Lamprechtshausen}
\tl_const:cn {c_phone_AT_ortsname_06276_tl} {Nu\ss dorf~am~Haunsberg}
\tl_const:cn {c_phone_AT_ortsname_06277_tl} {St.~Pantaleon~(Ober\"osterreich)}
\tl_const:cn {c_phone_AT_ortsname_06278_tl} {Ostermiething}
\tl_const:cn {c_phone_AT_ortsname_06412_tl} {Sankt~Johann~im~Pongau}
\tl_const:cn {c_phone_AT_ortsname_06413_tl} {Wagrain}
\tl_const:cn {c_phone_AT_ortsname_06414_tl} {Gro\ss arl}
\tl_const:cn {c_phone_AT_ortsname_06415_tl} {Schwarzach~im~Pongau}
\tl_const:cn {c_phone_AT_ortsname_06416_tl} {Lend}
\tl_const:cn {c_phone_AT_ortsname_06417_tl} {H\"uttschlag}
\tl_const:cn {c_phone_AT_ortsname_06418_tl} {Kleinarl}
\tl_const:cn {c_phone_AT_ortsname_06432_tl} {Bad~Hofgastein}
\tl_const:cn {c_phone_AT_ortsname_06433_tl} {Dorfgastein}
\tl_const:cn {c_phone_AT_ortsname_06434_tl} {Bad~Gastein}
\tl_const:cn {c_phone_AT_ortsname_06452_tl} {Radstadt}
\tl_const:cn {c_phone_AT_ortsname_06453_tl} {Filzmoos}
\tl_const:cn {c_phone_AT_ortsname_06454_tl} {Mandling}
\tl_const:cn {c_phone_AT_ortsname_06455_tl} {Untertauern}
\tl_const:cn {c_phone_AT_ortsname_06456_tl} {Obertauern}
\tl_const:cn {c_phone_AT_ortsname_06457_tl} {Flachau}
\tl_const:cn {c_phone_AT_ortsname_06458_tl} {H\"uttau}
\tl_const:cn {c_phone_AT_ortsname_06461_tl} {Dienten~am~Hochk\"onig}
\tl_const:cn {c_phone_AT_ortsname_06462_tl} {Bischofshofen}
\tl_const:cn {c_phone_AT_ortsname_06463_tl} {Annaberg-Lung\"otz}
\tl_const:cn {c_phone_AT_ortsname_06466_tl} {Werfenweng}
\tl_const:cn {c_phone_AT_ortsname_06467_tl} {M\"uhlbach~am~Hochk\"onig}
\tl_const:cn {c_phone_AT_ortsname_06468_tl} {Werfen}
\tl_const:cn {c_phone_AT_ortsname_06470_tl} {Atzmannsdorf}
\tl_const:cn {c_phone_AT_ortsname_06471_tl} {Tweng}
\tl_const:cn {c_phone_AT_ortsname_06472_tl} {Mauterndorf}
\tl_const:cn {c_phone_AT_ortsname_06473_tl} {Mariapfarr}
\tl_const:cn {c_phone_AT_ortsname_06474_tl} {Tamsweg}
\tl_const:cn {c_phone_AT_ortsname_06475_tl} {Ramingstein}
\tl_const:cn {c_phone_AT_ortsname_06476_tl} {Sankt~Margarethen~im~Lungau}
\tl_const:cn {c_phone_AT_ortsname_06477_tl} {Sankt~Michael~im~Lungau}
\tl_const:cn {c_phone_AT_ortsname_06478_tl} {Zederhaus}
\tl_const:cn {c_phone_AT_ortsname_06479_tl} {Muhr}
\tl_const:cn {c_phone_AT_ortsname_06483_tl} {G\"oriach}
\tl_const:cn {c_phone_AT_ortsname_06484_tl} {Lessach}
\tl_const:cn {c_phone_AT_ortsname_06541_tl} {Saalbach}
\tl_const:cn {c_phone_AT_ortsname_06542_tl} {Zell~am~See}
\tl_const:cn {c_phone_AT_ortsname_06543_tl} {Taxenbach}
\tl_const:cn {c_phone_AT_ortsname_06544_tl} {Rauris}
\tl_const:cn {c_phone_AT_ortsname_06545_tl} {Bruck~an~der~Gro\ss glocknerstra\ss e}
\tl_const:cn {c_phone_AT_ortsname_06546_tl} {Fusch~an~der~Gro\ss glocknerstra\ss e}
\tl_const:cn {c_phone_AT_ortsname_06547_tl} {Kaprun}
\tl_const:cn {c_phone_AT_ortsname_06548_tl} {Niedernsill}
\tl_const:cn {c_phone_AT_ortsname_06549_tl} {Piesendorf}
\tl_const:cn {c_phone_AT_ortsname_06562_tl} {Mittersill}
\tl_const:cn {c_phone_AT_ortsname_06563_tl} {Uttendorf}
\tl_const:cn {c_phone_AT_ortsname_06564_tl} {Krimml}
\tl_const:cn {c_phone_AT_ortsname_06565_tl} {Neukirchen~am~Gro\ss venediger}
\tl_const:cn {c_phone_AT_ortsname_06566_tl} {Bramberg~am~Wildkogel}
\tl_const:cn {c_phone_AT_ortsname_06582_tl} {Saalfelden~am~Steinernen~Meer}
\tl_const:cn {c_phone_AT_ortsname_06583_tl} {Leogang}
\tl_const:cn {c_phone_AT_ortsname_06584_tl} {Maria~Alm~am~Steinernen~Meer}
\tl_const:cn {c_phone_AT_ortsname_06588_tl} {Lofer}
\tl_const:cn {c_phone_AT_ortsname_06589_tl} {Unken}
\tl_const:cn {c_phone_AT_ortsname_0662_tl} {Salzburg}
\tl_const:cn {c_phone_AT_ortsname_07211_tl} {Reichenau~im~M\"uhlkreis}
\tl_const:cn {c_phone_AT_ortsname_07212_tl} {Zwettl~an~der~Rodl}
\tl_const:cn {c_phone_AT_ortsname_07213_tl} {Bad~Leonfelden}
\tl_const:cn {c_phone_AT_ortsname_07214_tl} {Reichenthal}
\tl_const:cn {c_phone_AT_ortsname_07215_tl} {Hellmons\"odt}
\tl_const:cn {c_phone_AT_ortsname_07216_tl} {Helfenberg}
\tl_const:cn {c_phone_AT_ortsname_07217_tl} {St.~Veit~im~M\"uhlkreis}
\tl_const:cn {c_phone_AT_ortsname_07218_tl} {Gro\ss traberg~(Oberneukirchen)}
\tl_const:cn {c_phone_AT_ortsname_07219_tl} {Vorderwei\ss enbach}
\tl_const:cn {c_phone_AT_ortsname_07221_tl} {H\"orsching}
\tl_const:cn {c_phone_AT_ortsname_07223_tl} {Enns}
\tl_const:cn {c_phone_AT_ortsname_07224_tl} {St.~Florian~(Linz-Land)}
\tl_const:cn {c_phone_AT_ortsname_07225_tl} {Hargelsberg}
\tl_const:cn {c_phone_AT_ortsname_07226_tl} {Wilhering}
\tl_const:cn {c_phone_AT_ortsname_07227_tl} {Neuhofen~an~der~Krems}
\tl_const:cn {c_phone_AT_ortsname_07228_tl} {Kematen~an~der~Krems}
\tl_const:cn {c_phone_AT_ortsname_07229_tl} {Traun}
\tl_const:cn {c_phone_AT_ortsname_07230_tl} {Altenberg~bei~Linz}
\tl_const:cn {c_phone_AT_ortsname_07231_tl} {Herzogsdorf}
\tl_const:cn {c_phone_AT_ortsname_07232_tl} {St.~Martin~im~M\"uhlkreis}
\tl_const:cn {c_phone_AT_ortsname_07233_tl} {Feldkirchen~an~der~Donau}
\tl_const:cn {c_phone_AT_ortsname_07234_tl} {Ottensheim}
\tl_const:cn {c_phone_AT_ortsname_07235_tl} {Gallneukirchen}
\tl_const:cn {c_phone_AT_ortsname_07236_tl} {Pregarten}
\tl_const:cn {c_phone_AT_ortsname_07237_tl} {St.~Georgen~an~der~Gusen}
\tl_const:cn {c_phone_AT_ortsname_07238_tl} {Mauthausen}
\tl_const:cn {c_phone_AT_ortsname_07239_tl} {Lichtenberg}
\tl_const:cn {c_phone_AT_ortsname_07240_tl} {Sipbachzell}
\tl_const:cn {c_phone_AT_ortsname_07241_tl} {Steinerkirchen~an~der~Traun}
\tl_const:cn {c_phone_AT_ortsname_07242_tl} {Wels}
\tl_const:cn {c_phone_AT_ortsname_07243_tl} {Marchtrenk}
\tl_const:cn {c_phone_AT_ortsname_07244_tl} {Sattledt}
\tl_const:cn {c_phone_AT_ortsname_07245_tl} {Lambach}
\tl_const:cn {c_phone_AT_ortsname_07246_tl} {Gunskirchen}
\tl_const:cn {c_phone_AT_ortsname_07247_tl} {Kematen~am~Innbach}
\tl_const:cn {c_phone_AT_ortsname_07248_tl} {Grieskirchen}
\tl_const:cn {c_phone_AT_ortsname_07249_tl} {Bad~Schallerbach}
\tl_const:cn {c_phone_AT_ortsname_07250_tl} {Maria~Neustift}
\tl_const:cn {c_phone_AT_ortsname_07251_tl} {Schiedlberg}
\tl_const:cn {c_phone_AT_ortsname_07252_tl} {Steyr}
\tl_const:cn {c_phone_AT_ortsname_07253_tl} {Wolfern}
\tl_const:cn {c_phone_AT_ortsname_07254_tl} {Gro\ss raming}
\tl_const:cn {c_phone_AT_ortsname_07255_tl} {Losenstein}
\tl_const:cn {c_phone_AT_ortsname_07256_tl} {Ternberg}
\tl_const:cn {c_phone_AT_ortsname_07257_tl} {Gr\"unburg}
\tl_const:cn {c_phone_AT_ortsname_07258_tl} {Bad~Hall}
\tl_const:cn {c_phone_AT_ortsname_07259_tl} {Sierning}
\tl_const:cn {c_phone_AT_ortsname_07260_tl} {Waldhausen~im~Strudengau}
\tl_const:cn {c_phone_AT_ortsname_07261_tl} {Sch\"onau~im~M\"uhlkreis}
\tl_const:cn {c_phone_AT_ortsname_07262_tl} {Perg}
\tl_const:cn {c_phone_AT_ortsname_07263_tl} {Bad~Zell}
\tl_const:cn {c_phone_AT_ortsname_07264_tl} {Windhaag~bei~Perg}
\tl_const:cn {c_phone_AT_ortsname_07265_tl} {Pabneukirchen}
\tl_const:cn {c_phone_AT_ortsname_07266_tl} {Bad~Kreuzen}
\tl_const:cn {c_phone_AT_ortsname_07267_tl} {M\"onchdorf}
\tl_const:cn {c_phone_AT_ortsname_07268_tl} {Grein}
\tl_const:cn {c_phone_AT_ortsname_07269_tl} {Baumgartenberg}
\tl_const:cn {c_phone_AT_ortsname_07272_tl} {Eferding}
\tl_const:cn {c_phone_AT_ortsname_07273_tl} {Aschach~an~der~Donau}
\tl_const:cn {c_phone_AT_ortsname_07274_tl} {Alkoven}
\tl_const:cn {c_phone_AT_ortsname_07276_tl} {Peuerbach}
\tl_const:cn {c_phone_AT_ortsname_07277_tl} {Waizenkirchen}
\tl_const:cn {c_phone_AT_ortsname_07278_tl} {Neukirchen~am~Walde}
\tl_const:cn {c_phone_AT_ortsname_07279_tl} {Haibach~ob~der~Donau}
\tl_const:cn {c_phone_AT_ortsname_07280_tl} {Schwarzenberg~am~B\"ohmerwald}
\tl_const:cn {c_phone_AT_ortsname_07281_tl} {Aigen-Schl\"agl}
\tl_const:cn {c_phone_AT_ortsname_07282_tl} {Neufelden}
\tl_const:cn {c_phone_AT_ortsname_07283_tl} {Sarleinsbach}
\tl_const:cn {c_phone_AT_ortsname_07284_tl} {Oberkappel}
\tl_const:cn {c_phone_AT_ortsname_07285_tl} {Hofkirchen~im~M\"uhlkreis}
\tl_const:cn {c_phone_AT_ortsname_07286_tl} {Lembach~im~M\"uhlkreis}
\tl_const:cn {c_phone_AT_ortsname_07287_tl} {Peilstein~im~M\"uhlviertel}
\tl_const:cn {c_phone_AT_ortsname_07288_tl} {Ulrichsberg}
\tl_const:cn {c_phone_AT_ortsname_07289_tl} {Rohrbach-Berg}
\tl_const:cn {c_phone_AT_ortsname_0732_tl} {Linz}
\tl_const:cn {c_phone_AT_ortsname_07353_tl} {Gaflenz}
\tl_const:cn {c_phone_AT_ortsname_07355_tl} {Weyer}
\tl_const:cn {c_phone_AT_ortsname_07357_tl} {Kleinreif\/ling}
\tl_const:cn {c_phone_AT_ortsname_07412_tl} {Ybbs~an~der~Donau}
\tl_const:cn {c_phone_AT_ortsname_07413_tl} {Marbach~an~der~Donau}
\tl_const:cn {c_phone_AT_ortsname_07414_tl} {Weins-Isperdorf}
\tl_const:cn {c_phone_AT_ortsname_07415_tl} {Altenmarkt~(Yspertal)}
\tl_const:cn {c_phone_AT_ortsname_07416_tl} {Wieselburg}
\tl_const:cn {c_phone_AT_ortsname_07432_tl} {Strengberg}
\tl_const:cn {c_phone_AT_ortsname_07433_tl} {Wallsee-Sindelburg}
\tl_const:cn {c_phone_AT_ortsname_07434_tl} {Haag}
\tl_const:cn {c_phone_AT_ortsname_07435_tl} {St.~Valentin~(Nieder\"osterreich)}
\tl_const:cn {c_phone_AT_ortsname_07442_tl} {Waidhofen~an~der~Ybbs}
\tl_const:cn {c_phone_AT_ortsname_07443_tl} {Ybbsitz}
\tl_const:cn {c_phone_AT_ortsname_07444_tl} {Opponitz}
\tl_const:cn {c_phone_AT_ortsname_07445_tl} {Hollenstein~an~der~Ybbs}
\tl_const:cn {c_phone_AT_ortsname_07448_tl} {Kematen~an~der~Ybbs}
\tl_const:cn {c_phone_AT_ortsname_07471_tl} {Neustadtl~an~der~Donau}
\tl_const:cn {c_phone_AT_ortsname_07472_tl} {Amstetten}
\tl_const:cn {c_phone_AT_ortsname_07473_tl} {Blindenmarkt}
\tl_const:cn {c_phone_AT_ortsname_07474_tl} {Euratsfeld}
\tl_const:cn {c_phone_AT_ortsname_07475_tl} {Hausmening~(Neuhofen~an~der~Ybbs)}
\tl_const:cn {c_phone_AT_ortsname_07476_tl} {Aschbach-Markt}
\tl_const:cn {c_phone_AT_ortsname_07477_tl} {St.~Peter~in~der~Au}
\tl_const:cn {c_phone_AT_ortsname_07478_tl} {Oed-Oehling}
\tl_const:cn {c_phone_AT_ortsname_07479_tl} {Ardagger}
\tl_const:cn {c_phone_AT_ortsname_07480_tl} {Langau~(Gaming)}
\tl_const:cn {c_phone_AT_ortsname_07482_tl} {Scheibbs}
\tl_const:cn {c_phone_AT_ortsname_07483_tl} {Oberndorf~an~der~Melk}
\tl_const:cn {c_phone_AT_ortsname_07484_tl} {G\"ostling~an~der~Ybbs}
\tl_const:cn {c_phone_AT_ortsname_07485_tl} {Gaming}
\tl_const:cn {c_phone_AT_ortsname_07486_tl} {Lunz~am~See}
\tl_const:cn {c_phone_AT_ortsname_07487_tl} {Gresten}
\tl_const:cn {c_phone_AT_ortsname_07488_tl} {Steinakirchen~am~Forst}
\tl_const:cn {c_phone_AT_ortsname_07489_tl} {Purgstall~an~der~Erlauf}
\tl_const:cn {c_phone_AT_ortsname_07562_tl} {Windischgarsten}
\tl_const:cn {c_phone_AT_ortsname_07563_tl} {Spital~am~Pyhrn}
\tl_const:cn {c_phone_AT_ortsname_07564_tl} {Hinterstoder}
\tl_const:cn {c_phone_AT_ortsname_07565_tl} {St.~Pankraz~(Ober\"osterreich)}
\tl_const:cn {c_phone_AT_ortsname_07566_tl} {Rosenau~am~Hengstpa\ss}
\tl_const:cn {c_phone_AT_ortsname_07582_tl} {Kirchdorf~an~der~Krems}
\tl_const:cn {c_phone_AT_ortsname_07583_tl} {Kremsm\"unster}
\tl_const:cn {c_phone_AT_ortsname_07584_tl} {Molln}
\tl_const:cn {c_phone_AT_ortsname_07585_tl} {Klaus~an~der~Pyhrnbahn}
\tl_const:cn {c_phone_AT_ortsname_07586_tl} {Pettenbach}
\tl_const:cn {c_phone_AT_ortsname_07587_tl} {Wartberg~an~der~Krems}
\tl_const:cn {c_phone_AT_ortsname_07588_tl} {Ried~im~Traunkreis}
\tl_const:cn {c_phone_AT_ortsname_07612_tl} {Gmunden}
\tl_const:cn {c_phone_AT_ortsname_07613_tl} {Laakirchen}
\tl_const:cn {c_phone_AT_ortsname_07614_tl} {Vorchdorf}
\tl_const:cn {c_phone_AT_ortsname_07615_tl} {Scharnstein}
\tl_const:cn {c_phone_AT_ortsname_07616_tl} {Gr\"unau~im~Almtal}
\tl_const:cn {c_phone_AT_ortsname_07617_tl} {Traunkirchen}
\tl_const:cn {c_phone_AT_ortsname_07618_tl} {Neukirchen~(Altm\"unster)}
\tl_const:cn {c_phone_AT_ortsname_07619_tl} {Kirchham}
\tl_const:cn {c_phone_AT_ortsname_07662_tl} {Seewalchen~am~Attersee}
\tl_const:cn {c_phone_AT_ortsname_07663_tl} {Steinbach~am~Attersee}
\tl_const:cn {c_phone_AT_ortsname_07664_tl} {Weyregg~am~Attersee}
\tl_const:cn {c_phone_AT_ortsname_07665_tl} {Unterach~am~Attersee}
\tl_const:cn {c_phone_AT_ortsname_07666_tl} {Attersee}
\tl_const:cn {c_phone_AT_ortsname_07667_tl} {St.~Georgen~im~Attergau}
\tl_const:cn {c_phone_AT_ortsname_07672_tl} {V\"ocklabruck}
\tl_const:cn {c_phone_AT_ortsname_07673_tl} {Schwanenstadt}
\tl_const:cn {c_phone_AT_ortsname_07674_tl} {Attnang-Puchheim}
\tl_const:cn {c_phone_AT_ortsname_07675_tl} {Ampflwang~im~Hausruckwald}
\tl_const:cn {c_phone_AT_ortsname_07676_tl} {Ottnang~am~Hausruck}
\tl_const:cn {c_phone_AT_ortsname_07682_tl} {V\"ocklamarkt}
\tl_const:cn {c_phone_AT_ortsname_07683_tl} {Frankenburg~am~Hausruck}
\tl_const:cn {c_phone_AT_ortsname_07684_tl} {Frankenmarkt}
\tl_const:cn {c_phone_AT_ortsname_07711_tl} {Suben}
\tl_const:cn {c_phone_AT_ortsname_07712_tl} {Sch\"arding}
\tl_const:cn {c_phone_AT_ortsname_07713_tl} {Schardenberg}
\tl_const:cn {c_phone_AT_ortsname_07714_tl} {Esternberg}
\tl_const:cn {c_phone_AT_ortsname_07716_tl} {M\"unzkirchen}
\tl_const:cn {c_phone_AT_ortsname_07717_tl} {St.~Aegidi}
\tl_const:cn {c_phone_AT_ortsname_07718_tl} {Waldkirchen~am~Wesen}
\tl_const:cn {c_phone_AT_ortsname_07719_tl} {Taufkirchen~an~der~Pram}
\tl_const:cn {c_phone_AT_ortsname_07722_tl} {Braunau~am~Inn}
\tl_const:cn {c_phone_AT_ortsname_07723_tl} {Altheim}
\tl_const:cn {c_phone_AT_ortsname_07724_tl} {Mauerkirchen}
\tl_const:cn {c_phone_AT_ortsname_07727_tl} {Ach}
\tl_const:cn {c_phone_AT_ortsname_07728_tl} {Schwand~im~Innkreis}
\tl_const:cn {c_phone_AT_ortsname_07729_tl} {Neukirchen~an~der~Enknach}
\tl_const:cn {c_phone_AT_ortsname_07732_tl} {Haag~am~Hausruck}
\tl_const:cn {c_phone_AT_ortsname_07733_tl} {Neumarkt~im~Hausruckkreis}
\tl_const:cn {c_phone_AT_ortsname_07734_tl} {Hofkirchen~an~der~Trattnach}
\tl_const:cn {c_phone_AT_ortsname_07735_tl} {Gaspoltshofen}
\tl_const:cn {c_phone_AT_ortsname_07736_tl} {Pram}
\tl_const:cn {c_phone_AT_ortsname_07742_tl} {Mattighofen}
\tl_const:cn {c_phone_AT_ortsname_07743_tl} {Maria~Schmolln}
\tl_const:cn {c_phone_AT_ortsname_07744_tl} {Munderfing}
\tl_const:cn {c_phone_AT_ortsname_07745_tl} {Lochen~am~See}
\tl_const:cn {c_phone_AT_ortsname_07746_tl} {Friedburg}
\tl_const:cn {c_phone_AT_ortsname_07747_tl} {Kirchberg~bei~Mattighofen}
\tl_const:cn {c_phone_AT_ortsname_07748_tl} {Eggelsberg}
\tl_const:cn {c_phone_AT_ortsname_07750_tl} {Andrichsfurt}
\tl_const:cn {c_phone_AT_ortsname_07751_tl} {St.~Martin~im~Innkreis}
\tl_const:cn {c_phone_AT_ortsname_07752_tl} {Ried~im~Innkreis}
\tl_const:cn {c_phone_AT_ortsname_07753_tl} {Eberschwang}
\tl_const:cn {c_phone_AT_ortsname_07754_tl} {Waldzell}
\tl_const:cn {c_phone_AT_ortsname_07755_tl} {Mettmach}
\tl_const:cn {c_phone_AT_ortsname_07757_tl} {Gurten}
\tl_const:cn {c_phone_AT_ortsname_07758_tl} {Obernberg~am~Inn}
\tl_const:cn {c_phone_AT_ortsname_07759_tl} {Antiesenhofen}
\tl_const:cn {c_phone_AT_ortsname_07762_tl} {Raab}
\tl_const:cn {c_phone_AT_ortsname_07763_tl} {Kopfing~im~Innkreis}
\tl_const:cn {c_phone_AT_ortsname_07764_tl} {Riedau}
\tl_const:cn {c_phone_AT_ortsname_07765_tl} {Lambrechten}
\tl_const:cn {c_phone_AT_ortsname_07766_tl} {Andorf}
\tl_const:cn {c_phone_AT_ortsname_07767_tl} {Eggerding}
\tl_const:cn {c_phone_AT_ortsname_07941_tl} {Neumarkt~im~M\"uhlkreis}
\tl_const:cn {c_phone_AT_ortsname_07942_tl} {Freistadt}
\tl_const:cn {c_phone_AT_ortsname_07943_tl} {Windhaag~bei~Freistadt}
\tl_const:cn {c_phone_AT_ortsname_07944_tl} {Sandl}
\tl_const:cn {c_phone_AT_ortsname_07945_tl} {St.~Oswald~bei~Freistadt}
\tl_const:cn {c_phone_AT_ortsname_07946_tl} {Gutau}
\tl_const:cn {c_phone_AT_ortsname_07947_tl} {Kefermarkt}
\tl_const:cn {c_phone_AT_ortsname_07948_tl} {Hirschbach~im~M\"uhlkreis}
\tl_const:cn {c_phone_AT_ortsname_07949_tl} {Rainbach~im~M\"uhlkreis}
\tl_const:cn {c_phone_AT_ortsname_07952_tl} {Weitersfelden}
\tl_const:cn {c_phone_AT_ortsname_07953_tl} {Liebenau}
\tl_const:cn {c_phone_AT_ortsname_07954_tl} {St.~Georgen~am~Walde}
\tl_const:cn {c_phone_AT_ortsname_07955_tl} {K\"onigswiesen}
\tl_const:cn {c_phone_AT_ortsname_07956_tl} {Unterwei\ss enbach}
\tl_const:cn {c_phone_AT_ortsname_0501_tl} {Virtuelles~privates~Netz}
\tl_const:cn {c_phone_AT_ortsname_0502_tl} {Virtuelles~privates~Netz}
\tl_const:cn {c_phone_AT_ortsname_0503_tl} {Virtuelles~privates~Netz}
\tl_const:cn {c_phone_AT_ortsname_0504_tl} {Virtuelles~privates~Netz}
\tl_const:cn {c_phone_AT_ortsname_0505_tl} {Virtuelles~privates~Netz}
\tl_const:cn {c_phone_AT_ortsname_0506_tl} {Virtuelles~privates~Netz}
\tl_const:cn {c_phone_AT_ortsname_0507_tl} {Virtuelles~privates~Netz}
\tl_const:cn {c_phone_AT_ortsname_0508_tl} {Virtuelles~privates~Netz}
\tl_const:cn {c_phone_AT_ortsname_0509_tl} {Virtuelles~privates~Netz}
\tl_const:cn {c_phone_AT_ortsname_0517_tl} {Virtuelles~privates~Netz}
\tl_const:cn {c_phone_AT_ortsname_057_tl} {Virtuelles~privates~Netz}
\tl_const:cn {c_phone_AT_ortsname_059_tl} {Virtuelles~privates~Netz}
\tl_const:cn {c_phone_AT_ortsname_0650_tl} {Mobilfunk}
\tl_const:cn {c_phone_AT_ortsname_0651_tl} {Mobilfunk}
\tl_const:cn {c_phone_AT_ortsname_0652_tl} {Mobilfunk}
\tl_const:cn {c_phone_AT_ortsname_0653_tl} {Mobilfunk}
\tl_const:cn {c_phone_AT_ortsname_0655_tl} {Mobilfunk}
\tl_const:cn {c_phone_AT_ortsname_0657_tl} {Mobilfunk}
\tl_const:cn {c_phone_AT_ortsname_0659_tl} {Mobilfunk}
\tl_const:cn {c_phone_AT_ortsname_0660_tl} {Mobilfunk}
\tl_const:cn {c_phone_AT_ortsname_0661_tl} {Mobilfunk}
\tl_const:cn {c_phone_AT_ortsname_0663_tl} {Mobilfunk}
\tl_const:cn {c_phone_AT_ortsname_0664_tl} {Mobilfunk}
\tl_const:cn {c_phone_AT_ortsname_0665_tl} {Mobilfunk}
\tl_const:cn {c_phone_AT_ortsname_0666_tl} {Mobilfunk}
\tl_const:cn {c_phone_AT_ortsname_0667_tl} {Mobilfunk}
\tl_const:cn {c_phone_AT_ortsname_0668_tl} {Mobilfunk}
\tl_const:cn {c_phone_AT_ortsname_0669_tl} {Mobilfunk}
\tl_const:cn {c_phone_AT_ortsname_067_tl} {Mobilfunk}
\tl_const:cn {c_phone_AT_ortsname_068_tl} {Mobilfunk}
\tl_const:cn {c_phone_AT_ortsname_069_tl} {Mobilfunk}
\tl_const:cn {c_phone_AT_ortsname_0711_tl} {Mehrwertdienst}
\tl_const:cn {c_phone_AT_ortsname_0718_tl} {Dial-Up-Zugang}
\tl_const:cn {c_phone_AT_ortsname_0720_tl} {Standortunabh\"angige~Rufnummer}
\tl_const:cn {c_phone_AT_ortsname_0780_tl} {Konvergenter~Dienst}
\tl_const:cn {c_phone_AT_ortsname_0800_tl} {Kostenloser~Dienst}
\tl_const:cn {c_phone_AT_ortsname_0804_tl} {Kostenloser~Dial-Up-Zugang}
\tl_const:cn {c_phone_AT_ortsname_0810_tl} {Dienst~mit~Maximaltarif}
\tl_const:cn {c_phone_AT_ortsname_0820_tl} {Dienst~mit~Maximaltarif}
\tl_const:cn {c_phone_AT_ortsname_0821_tl} {Dienst~mit~Maximaltarif}
\tl_const:cn {c_phone_AT_ortsname_0828_tl} {Dienst~mit~Maximaltarif}
\tl_const:cn {c_phone_AT_ortsname_089_tl} {Routingnummer}
\tl_const:cn {c_phone_AT_ortsname_0900_tl} {Mehrwertdienst}
\tl_const:cn {c_phone_AT_ortsname_0901_tl} {Mehrwertdienst}
\tl_const:cn {c_phone_AT_ortsname_0930_tl} {Mehrwertdienst}
\tl_const:cn {c_phone_AT_ortsname_0931_tl} {Mehrwertdienst}
\tl_const:cn {c_phone_AT_ortsname_0939_tl} {Mehrwert-Onlinedienst~(Dialer)}

\tl_const:Nn \c_phone_AT_landesadjektiv_tl {Austrian}
\bool_const:Nn \c_phone_AT_erlaubt_durchwahl_bool {\c_true_bool}

\clist_new:N \c_phone_AT_vorwahlen_clist
\clist_concat:NNN \c_phone_AT_vorwahlen_clist \c_phone_AT_ortsvorwahlen_clist \c_phone_AT_sondervorwahlen_clist

% Prüfe, ob eine Vorwahl als Heimatvorwahl zulässig ist.
% #1: Heimatvorwahl
\prg_new_protected_conditional:Npnn \phone_AT_heimatvorwahl_erlaubt:n #1 {T}
   {
      \clist_if_in:NnTF \c_phone_AT_ortsvorwahlen_clist {#1}
         {
            % Alle österreichischen Ortsvorwahlen können Heimatvorwahl sein.
            \prg_return_true:
         }
         {
            \msg_warning:nnn {phonenumbers} {invalid home area code} {#1}
            \prg_return_false:
         }
   }

% #1: Vorwahl, #2: Soll die führende Null ausgegeben werden?
\cs_new_protected:Npn \phone_AT_ziffernvorwahl_schreiben:nN #1#2
   {
      \bool_if:NTF #2
         {
            \phone_von_hinten_gruppiert_schreiben:n {#1}
         }
         {
            \phone_von_hinten_gruppiert_schreiben:x { \str_tail:n {#1} }
         }
   }

% #1: Vorwahl, #2: Folgt eine Rufnummer?
\cs_new_protected:Npn \phone_AT_vorwahl_schreiben:nn #1 #2
   {
      \bool_lazy_or:nnTF { \str_if_eq_p:Vn \l_phone_auslandsvorwahltyp_str {off} } { \str_if_eq_p:Vn \l_phone_heimatland_str {AT} }
         {
            \clist_if_in:NnT \c_phone_AT_sondervorwahlen_clist {#1}
               {
                  \str_if_eq:VnT \l_phone_vorwahldarstellung_str {place}
                     {
                        \str_set:Nn \l_phone_vorwahldarstellung_str {number}
                     }
               }

            \bool_lazy_and:nnF { \str_if_eq_p:Vn \l_phone_heimatland_str {AT} } { \str_if_eq_p:Vn \l_phone_heimatvorwahl_str {#1} }
               {
                  \str_case:Vn \l_phone_vorwahldarstellung_str
                     {
                        {number}
                           {
                              \bool_if:nTF {#2}
                                 {
                                    \str_if_eq:VnTF \l_phone_vorwahltrennung_str {brackets}
                                       {
                                          \phone_geklammerte_ziffernvorwahl_schreiben:nN {#1} \c_true_bool
                                          \tl_put_right:NV \l_phone_ausgabetext_tl \c_space_tl
                                       }
                                       {
                                          \phone_AT_ziffernvorwahl_schreiben:nN {#1} \c_true_bool

                                          \tl_put_right:Nx \l_phone_ausgabetext_tl
                                             {
                                                \str_case:VnF \l_phone_vorwahltrennung_str
                                                   {
                                                      {space} {\c_space_tl}
                                                      {hyphen} {\c_phone_bindestrich_tl}
                                                   }
                                                   {
                                                      \c_phone_schraegstrich_tl
                                                   }
                                             }
                                       }
                                 }
                                 {
                                    \phone_AT_ziffernvorwahl_schreiben:nN {#1} \c_true_bool
                                 }
                           }
                        {place}
                           {
                              \bool_if:nTF {#2}
                                 {
                                    \str_if_eq:VnT \l_phone_vorwahltrennung_str {brackets}
                                       {
                                          \tl_put_right:Nn \l_phone_ausgabetext_tl {(}
                                       }

                                    \tl_if_exist:cTF {c_phone_AT_ortsname_ #1 _tl}
                                       {
                                          \tl_put_right:Nv \l_phone_ausgabetext_tl {c_phone_AT_ortsname_ #1 _tl}
                                       }
                                       {
                                          \phone_AT_ziffernvorwahl_schreiben:nN {#1} \c_true_bool
                                       }

                                    \tl_put_right:Nx \l_phone_ausgabetext_tl
                                       {
                                          \str_case:VnF \l_phone_vorwahltrennung_str
                                             {
                                                {brackets} {) \c_space_tl}
                                                {space} {\c_space_tl}
                                                {hyphen} {\c_phone_bindestrich_tl}
                                             }
                                             {
                                                \c_phone_schraegstrich_tl
                                             }
                                       }
                                 }
                                 {
                                    \tl_if_exist:cTF {c_phone_AT_ortsname_ #1 _tl}
                                       {
                                          \tl_put_right:Nv \l_phone_ausgabetext_tl {c_phone_AT_ortsname_ #1 _tl}
                                       }
                                       {
                                          \phone_AT_ziffernvorwahl_schreiben:nN {#1} \c_true_bool
                                       }
                                 }
                           }
                        {place-and-number}
                           {
                              \tl_if_exist:cT {c_phone_AT_ortsname_ #1 _tl}
                                 {
                                    \tl_put_right:Nv \l_phone_ausgabetext_tl {c_phone_AT_ortsname_ #1 _tl}
                                    \tl_put_right:NV \l_phone_ausgabetext_tl \c_space_tl
                                 }

                              \str_if_eq:VnTF \l_phone_vorwahltrennung_str {brackets}
                                 {
                                    \phone_geklammerte_ziffernvorwahl_schreiben:nN {#1} \c_true_bool

                                    \bool_if:nT {#2}
                                       {
                                          \tl_put_right:NV \l_phone_ausgabetext_tl \c_space_tl
                                       }
                                 }
                                 {
                                    \phone_AT_ziffernvorwahl_schreiben:nN {#1} \c_true_bool

                                    \bool_if:nT {#2}
                                       {
                                          \tl_put_right:Nx \l_phone_ausgabetext_tl
                                             {
                                                \str_case:VnF \l_phone_vorwahltrennung_str
                                                   {
                                                      {space} {\c_space_tl}
                                                      {hyphen} {\c_phone_bindestrich_tl}
                                                   }
                                                   {
                                                      \c_phone_schraegstrich_tl
                                                   }
                                             }
                                       }
                                 }
                           }
                     }
               }
         }
         {
            \phone_gruppierte_auslandsvorwahl_schreiben:n {43}
            \tl_put_right:NV \l_phone_ausgabetext_tl \c_space_tl

            \str_if_eq:VnTF \l_phone_auslandsvorwahltrennung_str {brackets}
               {
                  \phone_geklammerte_ziffernvorwahl_schreiben:nN {#1} \c_false_bool
               }
               {
                  \phone_AT_ziffernvorwahl_schreiben:nN {#1} \c_false_bool
               }

            \bool_if:nT {#2}
               {
                  \tl_put_right:NV \l_phone_ausgabetext_tl \c_space_tl
               }
         }

      % Linktext schreiben, falls eine Rufnummer folgt
      \bool_if:nT {#2}
         {
            \str_put_right:Nx \l_phone_linktext_str {+43}
            \str_put_right:Nx \l_phone_linktext_str { \str_tail:n {#1} }
         }
   }

\cs_generate_variant:Nn \phone_AT_vorwahl_schreiben:nn {Vx}

% #1: Vorwahl, #2: Teilnehmerrufnummer
\cs_new_protected:Npn \phone_AT_festnetzteilnehmerrufnummernlaenge_ueberpruefen:Nn #1#2
   {
      \int_set:Nn \l_tmpa_int { \str_count:N #1 }
      \int_add:Nn \l_tmpa_int { \str_count:n {#2} }
      \int_add:Nn \l_tmpa_int { \str_count:N \l_phone_bereinigte_durchwahl_str }

      \int_compare:nNnTF {\l_tmpa_int} > {13}
         {
            % Gesamtnummer hat mehr als 13 Stellen
            \msg_warning:nnnn {phonenumbers} {number too long} {landline} {13}
         }
         {
            \int_set:Nn \l_tmpa_int { \str_count:n {#2} }
            \int_add:Nn \l_tmpa_int { \str_count:N \l_phone_bereinigte_durchwahl_str }

            \int_compare:nNnTF {\l_tmpa_int} < {5}
               {
                  % Teilnehmerrufnummer hat weniger als 5 Stellen
                  \msg_warning:nnn {phonenumbers} {subscriber number too short} {5}
               }
               {
                  \bool_lazy_and:nnTF { \str_if_eq_p:Vn #1 {01} } { \int_compare_p:nNn {\l_tmpa_int} < {7} }
                     {
                        % Wiener Teilnehmerrufnummer hat weniger als 7 Stellen
                        \msg_warning:nnn {phonenumbers} {subscriber number too short} {7}
                     }
                     {
                        \bool_lazy_and:nnTF
                           {
                              \bool_lazy_any_p:n
                                 {
                                    { \str_if_eq_p:Vn #1 {02236} }
                                    { \str_if_eq_p:Vn #1 {02252} }
                                    { \str_if_eq_p:Vn #1 {0316} }
                                    { \str_if_eq_p:Vn #1 {0463} }
                                    { \str_if_eq_p:Vn #1 {0512} }
                                    { \str_if_eq_p:Vn #1 {05572} }
                                    { \str_if_eq_p:Vn #1 {0662} }
                                    { \str_if_eq_p:Vn #1 {07242} }
                                    { \str_if_eq_p:Vn #1 {0732} }
                                 }
                           }
                           {
                              \int_compare_p:nNn {\l_tmpa_int} < {6}
                           }
                           {
                              % Teilnehmerrufnummer in bestimmten Ortsnetzen hat weniger als 6 Stellen
                              \msg_warning:nnn {phonenumbers} {subscriber number too short} {6}
                           }
                           {
                              \int_compare:nNnTF {\l_tmpa_int} > {9}
                                 {
                                    % Teilnehmerrufnummer hat mehr als 9 Stellen
                                    \msg_warning:nnn {phonenumbers} {subscriber number too long} {9}
                                 }
                                 {
                                    \bool_set_true:N \l_phone_teilnehmerrufnummer_gueltig_bool
                                 }
                           }
                     }
               }
         }
   }

% #1: Vorwahl, #2: Teilnehmerrufnummer
\cs_new_protected:Npn \phone_AT_festnetzteilnehmerrufnummer_ueberpruefen:Nn #1#2
   {
      \str_set:Nx \l_tmpa_str { \str_head:n {#2} }

      \bool_lazy_or:nnTF { \str_if_eq_p:Vn \l_tmpa_str {0} } { \str_if_eq_p:Vn \l_tmpa_str {1} }
         {
            \msg_warning:nnV {phonenumbers} {illegal start of subscriber number} \l_tmpa_str
         }
         {
            \phone_AT_festnetzteilnehmerrufnummernlaenge_ueberpruefen:Nn #1 {#2}
         }
   }

% #1: Vorwahl, #2: Teilnehmerrufnummer
\cs_new_protected:Npn \phone_AT_teilnehmerrufnummer_schreiben:Nn #1 #2
   {
      \str_if_empty:NTF #1
         {
            % Festnetznummer ohne Vorwahl
            \bool_if:NF \l_phone_eingabe_leer_bool
               {
                  \phone_AT_festnetzteilnehmerrufnummer_ueberpruefen:Nn #1 {#2}
               }
         }
         {
            \clist_if_in:NVTF \c_phone_AT_ortsvorwahlen_clist #1
               {
                  % Festnetznummer mit Vorwahl
                  \phone_AT_festnetzteilnehmerrufnummer_ueberpruefen:Nn #1 {#2}
               }
               {
                  % Mobilfunk-/Sondernummer
                  \str_set_eq:NN \l_tmpa_str #1
                  \str_put_right:Nn \l_tmpa_str {#2}

                  \str_case:VnF #1
                     {
                        {0517} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {9} {13} {VPN} }
                        {0718} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {10} {13} {dial~up} }
                        {0720} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {10} {13} {location~independant} }
                        {0780} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {10} {13} {convergent~service} }
                        {0800} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {10} {13} {freephone} }
                        {0804} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {10} {13} {dial~up} }
                        {0810} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {10} {13} {service} }
                        {0820} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {10} {13} {service} }
                        {0821} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {10} {13} {service} }
                        {0828} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {10} {13} {service} }
                        {0900} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {10} {13} {premium~service} }
                        {0901} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {10} {13} {premium~service} }
                        {0930} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {10} {13} {premium~service} }
                        {0931} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {10} {13} {premium~service} }
                        {0939} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {10} {13} {premium~service} }
                     }
                     {
                        \str_case:xn { \str_range:Nnn #1 {1} {3} }
                           {
                              {050} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {9} {13} {VPN} }
                              {057} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {9} {13} {VPN} }
                              {059} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {9} {13} {VPN} }
                              {065} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {9} {13} {mobile~phone} }
                              {066} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {9} {13} {mobile~phone} }
                              {067} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {9} {13} {mobile~phone} }
                              {068} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {9} {13} {mobile~phone} }
                              {069} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {9} {13} {mobile~phone} }
                           }
                     }

                  \str_if_empty:NF \l_phone_bereinigte_durchwahl_str
                     {
                        \msg_warning:nn {phonenumbers} {odd extension}
                     }
               }

            \bool_if:NTF \l_phone_teilnehmerrufnummer_gueltig_bool
               {
                  % Für gültige Nummern mit Vorwahl Linktext schreiben:
                  \str_put_right:Nn \l_phone_linktext_str {#2}
                  \str_put_right:NV \l_phone_linktext_str \l_phone_bereinigte_durchwahl_str
               }
               {
                  % Für ungültige Nummern mit Vorwahl Linktext löschen:
                  \str_clear:N \l_phone_linktext_str
               }
         }

      \bool_if:NTF \l_phone_teilnehmerrufnummer_gueltig_bool
         {
            \phone_von_hinten_gruppiert_schreiben:n {#2}
         }
         {
            \str_put_right:Nn \l_phone_ausgabetext_tl {#2}
         }

      \str_if_empty:NF \l_phone_bereinigte_durchwahl_str
         {
            \tl_put_right:NV \l_phone_ausgabetext_tl \c_phone_bindestrich_tl
            \phone_von_hinten_gruppiert_schreiben:V \l_phone_bereinigte_durchwahl_str
         }
   }

\cs_generate_variant:Nn \phone_AT_teilnehmerrufnummer_schreiben:Nn {Nx,NV}

\cs_new_protected:Npn \phone_AT_nummer_schreiben:
   {
      \str_if_eq:xnTF { \str_head:N \l_phone_bereinigte_nummer_str } {0}
         {
            \phone_enthaelt_vorwahl:NTF \l_phone_bereinigte_nummer_str
               {
                  \int_set:Nn \l_phone_hauptnummernlaenge_int { \str_count:N \l_phone_bereinigte_nummer_str }
                  \int_set:Nn \l_phone_vorwahllaenge_int { \str_count:N \l_phone_vorwahl_str }

                  \phone_AT_vorwahl_schreiben:Vx \l_phone_vorwahl_str
                     {
                        \int_compare_p:nNn {\l_phone_vorwahllaenge_int} < {\l_phone_hauptnummernlaenge_int}
                     }

                  \int_compare:nNnTF {\l_phone_vorwahllaenge_int} = {\l_phone_hauptnummernlaenge_int}
                     {
                        \msg_warning:nn {phonenumbers} {missing subscriber number}
                     }
                     {
                        \phone_AT_teilnehmerrufnummer_schreiben:Nx \l_phone_vorwahl_str
                           {
                              \str_range:Nnn \l_phone_bereinigte_nummer_str { \l_phone_vorwahllaenge_int + 1 } {-1}
                           }
                     }
               }
               {
                  \msg_warning:nn {phonenumbers} {invalid area code}
                  \tl_put_right:NV \l_phone_ausgabetext_tl \l_phone_bereinigte_nummer_str
                  \tl_put_right:NV \l_phone_ausgabetext_tl \l_phone_bereinigte_durchwahl_str
               }
         }
         {
            \phone_AT_teilnehmerrufnummer_schreiben:NV \c_empty_tl \l_phone_bereinigte_nummer_str
         }
   }

\cs_new_protected:Npn \phone_AT_vorwahlliste_ausgeben:n #1
   {
      \begin{tabbing}
      \hspace {4em} \= \kill

      \bool_set_false:N \l_phone_zeilenumbruch_bool

      \clist_map_inline:cn {c_phone_AT_ #1 _clist}
         {
            \bool_if:NTF \l_phone_zeilenumbruch_bool
               {
                  \\
               }
               {
                  \bool_gset_true:N \l_phone_zeilenumbruch_bool
               }

            \phone_von_hinten_gruppiert_schreiben:n {##1}
            \tl_use:N \l_phone_ausgabetext_tl
            \>
            \tl_if_exist:cT {c_phone_AT_ortsname_ ##1 _tl}
               {
                  \tl_use:c {c_phone_AT_ortsname_ ##1 _tl}
               }
         }
      \end{tabbing}
   }
